<?php

namespace App\Http\Controllers\Frontend\Alerts;

use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\RunView\runview;

use App\Http\Controllers\Frontend\Observations\ObserveController;
use App\Models\Stations\Station;

use DB;
use Illuminate\Support\Facades\Mail;
use App\Mail\Frontend\Stations\Alerts;

class AlertsController extends Controller
{
    public $ObserveController;

    public function __construct()
    {
        $this->ObserveController = new ObserveController();
    }

    public function index()
    {
        return view('frontend.alerts.index');
    }

    public function colombo()
    {
        return view('frontend.alerts.divisions.colombo');
    }

    public function observedMapWL($start, $end)
    {
        set_time_limit(0);
        $values = [];
        $stations = [];
        $end_response = null;

        if ((Carbon::parse($start) < Carbon::parse($end)) && (Carbon::parse($start) > Carbon::now() || Carbon::parse($end) > Carbon::now())) {
            return redirect()->route('frontend.alert.map.wl.obs', ['start' => Carbon::now()->format('Y-m-d H:00:00'), 'end' => Carbon::now()->format('Y-m-d H:00:00')])->withFlashWarning('Invalid Date range');
        }

        if ($start == $end) {
            $end = Carbon::parse($end)->addHour(1);
            $end_response = Carbon::parse($end)->subHour(1);
        } else {
            $end_response = $end;
        }

        $runs = runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->orderBy('station', 'asc')->get();

        if ($runs->isNotEmpty()) {
            foreach ($runs as $key => $run) {
                $run_data = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', $start)
                    ->where('time', '<=', $end)
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                if ($run->station == 'Diyasaru Uyana') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Ingurukade') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 1.2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Leecom WL Guage') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Wellampitiya') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 1.2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Wellawatta') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                if ($run->station == 'Yakbedda') {
                    $stations[$key]['name'] = $run->station;
                    if ($run_data['value'] >= 1.7) {
                        $stations[$key]['class'] = '#ffee58';
                        $stations[$key]['rgb'] = '255, 235, 59, 0.9';
                    } elseif ($run_data['value'] >= 2) {
                        $stations[$key]['class'] = '#ffa726';
                        $stations[$key]['rgb'] = '255, 152, 0, 0.7';
                    } else {
                        $stations[$key]['class'] = '#26c6da';
                        $stations[$key]['rgb'] = '0, 188, 212, 0.7';
                    }
                }

                $values[] = array(
                    'coordinates' => $this->ObserveController->getCoordinates($run->station),
                    'value' => $run_data['value'],
                    'updated' => $run_data['time']
                );
            }
        } else {
            echo 'Data not available';
        }
        //        dd($values);

        return view('frontend.alerts.maps.water-levels.observed')
            ->with(
                [
                    'values' => $values,
                    'stations' => $stations,
                    'start' => $start,
                    'end' => $end_response
                ]
            );
    }

    public function getFormData(Request $request)
    {
        set_time_limit(0);
        if ($request->has('start_date')) {
            $start = $request->input('start_date');
            $end = $request->input('end_date');

            return redirect()->route('frontend.alert.map.wl.obs', ['start' => $start, 'end' => $end]);
        }
    }

    public function stationInactiveMails()
    {
        set_time_limit(0);

        $active_stations = [];

        $stations = Station::select('name')->where('id', '<', 200000)->get();

        if ($stations->isNotEmpty()) {
            foreach ($stations as $station) {
                if ($station->name == 'Orugodawatta') {
                    $runview = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('name', 'CUrW IoT')
                        ->where('end_date', '>', Carbon::now()->subMonth(1))
                        ->where('start_date', '!=', null)
                        ->first();
                } else {
                    $runview = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->whereIn('name', ['CUrW IoT', 'Leecom', 'A&T Labs'])
                        ->where('end_date', '>', Carbon::now()->subMonth(1))
                        ->where('start_date', '!=', null)
                        ->first();
                }

                if ($runview !== null) {
                    $data = $runview->data()
                        ->orderBy('time', 'desc')
                        ->first();

                    if (Carbon::parse($data['time'])->diffInHours(Carbon::now()) >= 6) {
                        $active_stations[] = array(
                            'name' => $runview->station,
                            'time' => $data['time'],
                            'updated' => Carbon::parse($data['time'])->diffForHumans()
                        );
                    }
                }
            }
        }

        // /*if ($active_stations !== []) {
        //     // Mail::to(['ovindushamal@gmail.com'])->send(new Alerts($active_stations));
        //     Mail::to(['ovindushamal@gmail.com', 'shasiniumesha274@gmail.com', 'muditha.danta@eng.pdn.ac.lk'])->send(new Alerts($active_stations));
        // }*/

        return 'Successfull';
    }
}
