<?php

namespace App\Http\Controllers\Frontend\Graphs;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\RunView\runview;
use App\Models\Stations\Station;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;
use DateTime;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\File;

class GraphsController extends Controller
{
    public function hourlyIndex()
    {
        $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

        return view('frontend.graphs.hourly.index')->with(['types' => $types]);
    }

    public function hourlyCreate(Request $request)
    {
        $date = null;
        $stations = null;
        $runs = (array)null;
        $obs_values = (array)null;
        $f_runs = (array)null;
        $data = null;
        $start_time = null;
        $end_time = null;
        $all_data = null;
        $source = null;

        if ($request->has('data_type')) {
            $type = $request->input('type');
            $source = $request->input('source');
            $obs_station = $request->input('obs_station');
            $variable = $request->input('variable');
            $start_date = $request->input('start_date');
            $end_date = $request->input('end_date');
            $start_time = $start_date . " 00:00:00";
            $end_time = $end_date . " 23:00:00";
            $start_lat = $request->input('start_lat');
            $end_lat = $request->input('end_lat');
            $start_long = $request->input('start_long');
            $end_long = $request->input('end_long');

            if ($request->input('data_type') == 'by_station') {
                if ($request->has('stations')) {
                    $stations = $request->input('stations');
                }

                // Get all stations data
                if ($stations != null) {
                    foreach ($stations as $station) {
                        if ($variable == 'Precipitation') {
                            $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                        } else {
                            $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                        }

                    }
                }

//                dd($runs);

                // Observed station data
                if ($obs_station == null) {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                    $obs_station = $station;
                } else {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
                }


                if ($obs_runs != null) {
                    $obs_values = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
                }

                $display_data = array(
                    'variable' => $variable,
                    'type' => $type,
                    'source' => $source,
                    'stations' => $stations,
                    'obs_station' => $obs_station
                );

//                dd($runs);

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $runs);
                Cache::forever('source', $source);
                Cache::forever('obs_values', $obs_values);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);

                if (empty(array_filter($runs))) {
                    return redirect()->route('frontend.graphs.hourly.index')->withFlashWarning('Data not available for these inputs');
                } else {
                    return redirect()->route('frontend.graphs.hourly.stations');
                }
            }

            if ($request->input('data_type') == 'by_forecast') {

                $types = $request->input('types');
                $station = $request->input('station');

                // Get runview data
                foreach ($types as $key => $type) {
                    if ($variable == 'Precipitation') {
                        $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                    } else {
                        $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                    }
                }

                $forecasts = null;
                // Get data from Data model
                if ($f_runs != null) {
                    foreach ($f_runs as $key => $f_run) {
                        if ($f_run != null) {
                            $forecasts['values'][] = $f_run->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->orderBy('time', 'asc')->get()->toArray();

                            $forecasts['types'][] = $f_run->type;
                        }
                    }
                }

                // Observed station data
                if ($obs_station == null) {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                    $obs_station = $station;
                } else {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
                }


                if ($obs_runs != null) {
                    $forecasts['ob_values'] = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
                }

                $display_data = array(
                    'variable' => $variable,
                    'types' => $types,
                    'source' => $source,
                    'station' => $station,
                    'obs_station' => $obs_station
                );

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $f_runs);
                Cache::forever('source', $source);
                Cache::forever('forecasts', $forecasts);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);

                if (!empty(array_filter($forecasts['values']))) {
                    return redirect()->route('frontend.graphs.hourly.types');

                } else {
                    return redirect()->route('frontend.graphs.hourly.index')->withFlashWarning('Data not available for these inputs');
                }
            }

            if ($request->input('data_type') == 'by_coordinates') {

                // Get stations
                $stations = Station::where('longitude', '<=', $end_long)->where('longitude', '>=', $start_long)->where('latitude', '<=', $end_lat)->where('latitude', '>=', $start_lat)->whereNotIn('name', ['IBATTARA2', 'IBATTARA3', 'IBATTARA4'])->get();

                if ($stations != null) {
                    foreach ($stations as $station) {
                        $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                    }
                }

                // Observed station data
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->where('unit', 'mm')->first();


                $display_data = array(
                    'variable' => $variable,
                    'type' => $type,
                    'source' => $source,
                    'stations' => $stations
                );

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $runs);
                Cache::forever('source', $source);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);
                Cache::forever('obs_runs', $obs_runs);

                if (empty(array_filter($runs))) {
                    return redirect()->route('frontend.graphs.hourly.index')->withFlashWarning('Data not available for these inputs');
                } else {
                    return redirect()->route('frontend.graphs.hourly.coordinates');
                }
            }
        }


    }

    public
    function hourlyStations(Request $request)
    {
        // Get cache data
        $start_time = Cache::get('start_time');
        $end_time = Cache::get('end_time');
        $display_data = Cache::get('display_data');
        $runs = Cache::get('runs');
        $source = Cache::get('source');
        $obs_values = Cache::get('obs_values');

        // Put data to views
        if ($runs == null) {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.hourly.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        } else {
            return view('frontend.graphs.hourly.stations')->with(['runs' => array_filter($runs), 'obs_values' => $obs_values, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data, 'source' => $source]);
        }
    }


    public
    function hourlyTypes(Request $request)
    {
        // Re creating data set from daily input parameters
        $display_data = Cache::get('display_data');
        if (isset($display_data['types'])) {
            $types = $display_data['types'];
            $source = Cache::get('source');
            $variable = $display_data['variable'];
            $station = $display_data['station'];
            $obs_station = $display_data['obs_station'];
            $start_time = Cache::get('start_time');
            $end_time = Cache::get('end_time');

            // Get data from runview
            foreach ($types as $key => $type) {
                if ($variable == 'Precipitation') {
                    $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                } else {
                    $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                }
            }

            $forecasts = null;
            // Get data from Data model
            if ($f_runs != null) {
                foreach ($f_runs as $key => $f_run) {
                    if ($f_run != null) {
                        $forecasts['values'][] = $f_run->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->orderBy('time', 'asc')->get()->toArray();

                        $forecasts['types'][] = $f_run->type;
                    }
                }
            }

            // Observed station data
            if ($obs_station == null) {
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                $obs_station = $station;
            } else {
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
            }

            $obs_values = null;
            if ($obs_runs != null) {
                $forecasts['ob_values'] = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
            }

            $display_data = array(
                'variable' => $variable,
                'types' => $types,
                'source' => $source,
                'station' => $station,
                'obs_station' => $obs_station
            );

            // Put data to views
            Cache::flush();

            Cache::forever('forecasts', $forecasts);
            Cache::forever('source', $source);
            Cache::forever('start_time', $start_time);
            Cache::forever('end_time', $end_time);
            Cache::forever('display_data', $display_data);

            return view('frontend.graphs.hourly.forecast-type')->with(['forecasts' => $forecasts, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data]);
        } else {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.hourly.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        }
    }

    public
    function hourlyCoordinates(Request $request)
    {
        // Get cache data
        $start_time = Cache::get('start_time');
        $source = Cache::get('source');
        $end_time = Cache::get('end_time');
        $display_data = Cache::get('display_data');
        $obs_runs = Cache::get('obs_runs');
        $runs = Cache::get('runs');

        // Put data to views
        if ($runs == null) {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.hourly.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        } else {
            return view('frontend.graphs.hourly.coordinates')->with(['runs' => array_filter($runs), 'obs_runs' => $obs_runs, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data, 'source' => $source]);
        }
    }

    public
    function dailyIndex()
    {
        return view('frontend.graphs.daily.index');
    }

    public
    function dailyCreate(Request $request)
    {
        $date = null;
        $stations = null;
        $runs = (array)null;
        $obs_values = (array)null;
        $f_runs = (array)null;
        $data = null;
        $start_time = null;
        $end_time = null;
        $all_data = null;
        $source = null;

        if ($request->has('data_type')) {
            $type = $request->input('type');
            $source = $request->input('source');
            $obs_station = $request->input('obs_station');
            $variable = $request->input('variable');
            $start_date = $request->input('start_date');
            $end_date = $request->input('end_date');
            $start_time = $start_date . " 00:00:00";
            $end_time = $end_date . " 23:00:00";
            $start_lat = $request->input('start_lat');
            $end_lat = $request->input('end_lat');
            $start_long = $request->input('start_long');
            $end_long = $request->input('end_long');

            if ($request->input('data_type') == 'by_station') {
                if ($request->has('stations')) {
                    $stations = $request->input('stations');
                }

                // Get all stations data
                if ($stations != null) {
                    foreach ($stations as $station) {
                        if ($variable == 'Precipitation') {
                            $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                        } else {
                            $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                        }

                    }
                }

//                dd($runs);

                // Observed station data
                if ($obs_station == null) {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                    $obs_station = $station;
                } else {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
                }


                if ($obs_runs != null) {
                    $obs_values = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
                }

                $display_data = array(
                    'variable' => $variable,
                    'type' => $type,
                    'source' => $source,
                    'stations' => $stations,
                    'obs_station' => $obs_station
                );

//                dd($runs);

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $runs);
                Cache::forever('source', $source);
                Cache::forever('obs_values', $obs_values);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);

                if (empty(array_filter($runs))) {
                    return redirect()->route('frontend.graphs.daily.index')->withFlashWarning('Data not available for these inputs');
                } else {
                    return redirect()->route('frontend.graphs.daily.stations');
                }
            }

            if ($request->input('data_type') == 'by_forecast') {

                $types = $request->input('types');
                $station = $request->input('station');

                // Get runview data
                foreach ($types as $key => $type) {
                    if ($variable == 'Precipitation') {
                        $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                    } else {
                        $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                    }
                }

                $forecasts = null;
                // Get data from Data model
                if ($f_runs != null) {
                    foreach ($f_runs as $key => $f_run) {
                        if ($f_run != null) {
                            $forecasts['values'][] = $f_run->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->orderBy('time', 'asc')->get()->toArray();

                            $forecasts['types'][] = $f_run->type;
                        }
                    }
                }

                // Observed station data
                if ($obs_station == null) {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                    $obs_station = $station;
                } else {
                    $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
                }


                if ($obs_runs != null) {
                    $forecasts['ob_values'] = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
                }

                $display_data = array(
                    'variable' => $variable,
                    'types' => $types,
                    'source' => $source,
                    'station' => $station,
                    'obs_station' => $obs_station
                );

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $f_runs);
                Cache::forever('source', $source);
                Cache::forever('forecasts', $forecasts);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);

                if (!empty(array_filter($forecasts['values']))) {
                    return redirect()->route('frontend.graphs.daily.types');

                } else {
                    return redirect()->route('frontend.graphs.daily.index')->withFlashWarning('Data not available for these inputs');
                }
            }

            if ($request->input('data_type') == 'by_coordinates') {

                // Get stations
                $stations = Station::where('longitude', '<=', $end_long)->where('longitude', '>=', $start_long)->where('latitude', '<=', $end_lat)->where('latitude', '>=', $start_lat)->whereNotIn('name', ['IBATTARA2', 'IBATTARA3', 'IBATTARA4'])->get();

                if ($stations != null) {
                    foreach ($stations as $station) {
                        $runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                    }
                }

                // Observed station data
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->where('unit', 'mm')->first();


                $display_data = array(
                    'variable' => $variable,
                    'type' => $type,
                    'source' => $source,
                    'stations' => $stations
                );

                // Put data to views
                Cache::flush();

                Cache::forever('runs', $runs);
                Cache::forever('source', $source);
                Cache::forever('start_time', $start_time);
                Cache::forever('end_time', $end_time);
                Cache::forever('display_data', $display_data);
                Cache::forever('obs_runs', $obs_runs);

                if (empty(array_filter($runs))) {
                    return redirect()->route('frontend.graphs.daily.index')->withFlashWarning('Data not available for these inputs');
                } else {
                    return redirect()->route('frontend.graphs.daily.coordinates');
                }
            }
        }


    }

    public
    function dailyStations(Request $request)
    {
        // Get cache data
        $start_time = Cache::get('start_time');
        $end_time = Cache::get('end_time');
        $display_data = Cache::get('display_data');
        $runs = Cache::get('runs');
        $source = Cache::get('source');
        $obs_values = Cache::get('obs_values');

        // Put data to views
        if ($runs == null) {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.daily.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        } else {
            return view('frontend.graphs.daily.stations')->with(['runs' => array_filter($runs), 'obs_values' => $obs_values, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data, 'source' => $source]);
        }
    }

    public
    function dailyTypes(Request $request)
    {
        // Re creating data set from daily input parameters
        $display_data = Cache::get('display_data');
        if (isset($display_data['types'])) {
            $types = $display_data['types'];
            $source = Cache::get('source');
            $variable = $display_data['variable'];
            $station = $display_data['station'];
            $obs_station = $display_data['obs_station'];
            $start_time = Cache::get('start_time');
            $end_time = Cache::get('end_time');

            // Get data from runview
            foreach ($types as $key => $type) {
                if ($variable == 'Precipitation') {
                    $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('source', $source)->first();
                } else {
                    $f_runs[] = Runview::where('variable', $variable)->where('type', $type)->where('station', $station)->where('name', 'cloud-1')->first();
                }
            }

            $forecasts = null;
            // Get data from Data model
            if ($f_runs != null) {
                foreach ($f_runs as $key => $f_run) {
                    if ($f_run != null) {
                        $forecasts['values'][] = $f_run->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->orderBy('time', 'asc')->get()->toArray();

                        $forecasts['types'][] = $f_run->type;
                    }
                }
            }

            // Observed station data
            if ($obs_station == null) {
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $station)->first();
                $obs_station = $station;
            } else {
                $obs_runs = Runview::where('variable', $variable)->where('type', 'Observed')->where('station', $obs_station)->first();
            }

            $obs_values = null;
            if ($obs_runs != null) {
                $forecasts['ob_values'] = $obs_runs->data()->where('time', '<=', $end_time)->where('time', '>=', $start_time)->get()->toArray();
            }

            $display_data = array(
                'variable' => $variable,
                'types' => $types,
                'source' => $source,
                'station' => $station,
                'obs_station' => $obs_station
            );

            // Put data to views
            Cache::flush();

            Cache::forever('forecasts', $forecasts);
            Cache::forever('source', $source);
            Cache::forever('start_time', $start_time);
            Cache::forever('end_time', $end_time);
            Cache::forever('display_data', $display_data);

            return view('frontend.graphs.daily.forecast-type')->with(['forecasts' => $forecasts, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data]);
        } else {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.daily.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        }
    }

    public
    function dailyCoordinates(Request $request)
    {
        // Get cache data
        $start_time = Cache::get('start_time');
        $end_time = Cache::get('end_time');
        $display_data = Cache::get('display_data');
        $obs_runs = Cache::get('obs_runs');
        $runs = Cache::get('runs');
        $source = Cache::get('source');

        // Put data to views
        if ($runs == null) {
            $types = Runview::select('type')->distinct()->orderBy('type', 'asc')->get();

            return redirect()->route('frontend.graphs.daily.index')->with(['flash_info' => 'Session has expired, create new graph', 'types' => $types]);
        } else {
            return view('frontend.graphs.daily.coordinates')->with(['runs' => array_filter($runs), 'obs_runs' => $obs_runs, 'start_time' => $start_time, 'end_time' => $end_time, 'display_data' => $display_data, 'source' => $source]);
        }
    }

    public
    function mapIndex()
    {
        $exists = Storage::disk('local')->exists('public/mnt');
        $directories = Storage::allDirectories();
        // dd($exists);
        return view('frontend.graphs.maps.index');
    }

    public
    function getRunID(Request $request)
    {
        $wrf_no = $request->input('wrf_no');
        $run_date = $request->input('run_date');

        $base_path = 'curwsl_nfs/output';

        if (File::isDirectory($base_path . '/' . $wrf_no . '/' . $run_date . '/')) {
            $run_id_paths_count = File::directories($base_path . '/' . $wrf_no . '/' . $run_date . '/');
            return response(['data' => $run_id_paths_count]);
        } else {
            $run_id_paths_count = 0;
            return response(['data' => $run_id_paths_count]);
        }


    }

    public
    function mapsCreate(Request $request)
    {
        $wrf_no = $request->input('wrf_no');
        $run_date = $request->input('run_date');
        $run_id = $request->input('run_id');
        $image_date = $request->input('image_date');
        $sat_image_date = $request->input('image_date');
        $image_date = $image_date . '-00';

        $base_path = 'curwsl_nfs';
        $wrf_img_path = $base_path . '/output/' . $wrf_no . '/' . $run_date . '/' . $run_id . '/wrf_inst_' . $image_date . '.png';
        $sat_img_path = $base_path . '/sat/jaxa_sat_' . $sat_image_date . '.png';
        $namelist_path = $base_path . '/output/' . $wrf_no . '/' . $run_date . '/' . $run_id . '/namelist.input';

        $wrf_img_exits = File::exists($wrf_img_path);

        if ($wrf_img_exits == true) {
            $wrf_img = '/' . $wrf_img_path;
            $namelist = file($namelist_path);
            $sat_img = '/' . $sat_img_path;

//            $wrf_img = Storage::setVisibility($wrf_img, 'public');
//            $sat_img = Storage::setVisibility($sat_img, 'public');

            $data = array(
                'wrf_img' => $wrf_img,
                'namelist' => $namelist,
                'sat_img' => $sat_img,
                'wrf_no' => $wrf_no,
                'run_date' => $run_date,
                'run_id' => $run_id,
                'image_date' => $image_date
            );

            Cache::flush();
            Cache::forever('data', $data);

            return redirect()->route('frontend.graphs.maps.show');
        } else {
            return redirect()->route('frontend.graphs.maps.index')->withFlashInfo('Images are not available on this image date');
        }
    }

    public
    function mapsShow()
    {
        $data = Cache::get('data');

        if ($data) {
            $new_data = array(
                'wrf_img' => $data['wrf_img'],
                'namelist' => $data['namelist'],
                'sat_img' => $data['sat_img'],
                'wrf_no' => $data['wrf_no'],
                'run_date' => $data['run_date'],
                'run_id' => $data['run_id'],
                'image_date' => $data['image_date']
            );

            Cache::flush();
            Cache::forever('data', $new_data);

//            dd($new_data['wrf_img']);
        }

        return view('frontend.graphs.maps.show')->with(['data' => $new_data]);
    }
}
