<?php

namespace App\Http\Controllers\Frontend\Observations;

use App\Http\Controllers\Controller;
use App\Models\IOT\runview;
use App\Models\IOT\station;
use Carbon\Carbon;
use DB;

class ObserveController extends Controller
{
    // Index for stations
    public function index()
    {
        $stations = Runview::select('station')
            ->where('source', 'WeatherStation')
            ->where('type', 'Observed')
            ->distinct()
            ->orderBy('station', 'asc')
            ->get();

        return view('frontend.observations.index')->with(['stations' => $stations]);
    }

    // Index for stations - CURW DB Version
    public function indexCurw()
    {
        $stations = \App\Models\Runview\runview::select('station')
            ->where('source', 'WeatherStation')
            ->where('type', 'Observed')
            ->distinct()
            ->orderBy('station', 'asc')
            ->get();

        return view('frontend.observations.index-curw')->with(['stations' => $stations]);
    }

    // Single Station Data
    public function station($station)
    {
        date_default_timezone_set('Asia/Colombo');

        // Check weather station result status
        $result = null;
        $result_preci = null;
        $today = Carbon::today();

        if ($station == 'Orugodawatta') {
            $runview_preci = runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        }
//        elseif ($station->name == 'Hingurana') {
//            $runview_preci = runview::where('station', $station)
//                ->where('variable', 'Precipitation')
//                ->where('source', 'WeatherStation')
//                ->where('name', 'A&T Labs')
//                ->where('start_date', '!=', null)
//                ->first();
//
////                    dd($runview_preci);
//        }
        else {
            $runview_preci = runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_preci !== null) {
            $result = $runview_preci
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();

            $result_preci = $runview_preci
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        // Set values
        $values = array(
            'station' => $station,
            'coordinates' => $this->getCoordinates($station),
            'humidity' => $this->getHumidity($station),
            'temperature' => $this->getTemperature($station),
            'windspeed' => $this->getWindSpeed($station),
            'windgust' => $this->getWindGust($station),
            'solarradiation' => $this->getSolarRadiation($station),
            'winddirection' => $this->getWindDirection($station),
            'updated' => Carbon::parse($result_preci['time'])->diffForHumans(),
            'live_temperature' => $this->getTemperatureLive($station),
            'result' => $result
        );

//        if ($this->getPrecipitation($station) == null) {
//            echo "Sorry Weather Station is temporary down or not available, Check back later. Thank you for the patient!";
//            exit;
//        }

        return view('frontend.observations.view')->with(['values' => $values]);
    }

    // Single Station Data - CURW DB Version
    public function stationCurw($station)
    {
        date_default_timezone_set('Asia/Colombo');

        // Check weather station result status
        $result = null;
        $result_preci = null;
        $today = Carbon::today();

        if ($station == 'Orugodawatta') {
            $runview_preci = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        }
//        elseif ($station->name == 'Hingurana') {
//            $runview_preci = \App\Models\RunView\runview::where('station', $station)
//                ->where('variable', 'Precipitation')
//                ->where('source', 'WeatherStation')
//                ->where('name', 'A&T Labs')
//                ->where('start_date', '!=', null)
//                ->first();
//
////                    dd($runview_preci);
//        }
        else {
            $runview_preci = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_preci !== null) {
            $result = $runview_preci
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();

            $result_preci = $runview_preci
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        // Set values
        $values = array(
            'station' => $station,
            'coordinates' => $this->getCoordinates($station),
            'humidity' => $this->getHumidityCurw($station),
            'temperature' => $this->getTemperatureCurw($station),
            'windspeed' => $this->getWindSpeedCurw($station),
            'windgust' => $this->getWindGustCurw($station),
            'solarradiation' => $this->getSolarRadiationCurw($station),
            'winddirection' => $this->getWindDirectionCurw($station),
            'updated' => Carbon::parse($result_preci['time'])->diffForHumans(),
            'live_temperature' => $this->getTemperatureLiveCurw($station),
            'result' => $result
        );

//        if ($this->getPrecipitationCurw($station) == null) {
//            echo "Sorry Weather Station is temporary down or not available, Check back later. Thank you for the patient!";
//            exit;
//        }

        return view('frontend.observations.view-curw')->with(['values' => $values]);
    }

    // Get coordinates of the station
    public function getCoordinates($station)
    {
        $coordinates = null;

        $coordinates = Station::select(['latitude', 'longitude'])->where('name', $station)->first();
        if ($coordinates !== null) {
            $coordinates->toArray();
        }
        return $coordinates;
    }

    // Response for ajax call on table values
    public function getStaticValues($station)
    {
        date_default_timezone_set('Asia/Colombo');

        $result_preci = null;

        if ($station == 'Orugodawatta') {
            $runview_preci = runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        }
//        elseif ($station->name == 'Hingurana') {
//            $runview_preci = runview::where('station', $station)
//                ->where('variable', 'Precipitation')
//                ->where('source', 'WeatherStation')
//                ->where('name', 'A&T Labs')
//                ->where('start_date', '!=', null)
//                ->first();
//
////                    dd($runview_preci);
//        }
        else {
            $runview_preci = runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_preci !== null) {
            $result_preci = $runview_preci
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        $values = array(
            'humidity' => $this->getHumidity($station),
            'temperature' => $this->getTemperature($station),
            'windspeed' => $this->getWindSpeed($station),
            'windgust' => $this->getWindGust($station),
            'solarradiation' => $this->getSolarRadiation($station),
            'winddirection' => $this->getWindDirection($station),
            'updated' => Carbon::parse($result_preci['time'])->diffForHumans()
        );

        return $values;
    }

    // Response for ajax call on table values - CURW DB Version
    public function getStaticValuesCurw($station)
    {
        date_default_timezone_set('Asia/Colombo');

        $result_preci = null;

        if ($station == 'Orugodawatta') {
            $runview_preci = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        }
//        elseif ($station->name == 'Hingurana') {
//            $runview_preci = \App\Models\RunView\runview::where('station', $station)
//                ->where('variable', 'Precipitation')
//                ->where('source', 'WeatherStation')
//                ->where('name', 'A&T Labs')
//                ->where('start_date', '!=', null)
//                ->first();
//
////                    dd($runview_preci);
//        }
        else {
            $runview_preci = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_preci !== null) {
            $result_preci = $runview_preci
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        $values = array(
            'humidity' => $this->getHumidityCurw($station),
            'temperature' => $this->getTemperatureCurw($station),
            'windspeed' => $this->getWindSpeedCurw($station),
            'windgust' => $this->getWindGustCurw($station),
            'solarradiation' => $this->getSolarRadiationCurw($station),
            'winddirection' => $this->getWindDirectionCurw($station),
            'updated' => Carbon::parse($result_preci['time'])->diffForHumans()
        );

        return $values;
    }

    // Getting Humidity Data
    public function getHumidity($station)
    {
        $humidity = null;

        $runview_humidity = runview::where('station', $station)
            ->where('variable', 'Humidity')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_humidity !== null) {
            $humidity = $runview_humidity
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first()
                ->toArray();
        }

        return $humidity;
    }

    // Getting Humidity Data - CURW DB Version
    public function getHumidityCurw($station)
    {
        $humidity = null;

        $runview_humidity = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'Humidity')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_humidity !== null) {
            $humidity = $runview_humidity
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $humidity;
    }

    // Getting Temperature Data
    public function getTemperature($station)
    {
        $temperature = null;

        $runview_temperature = runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $temperature;
    }

    // Getting Temperature Data - CURW DB Version
    public function getTemperatureCurw($station)
    {
        $temperature = null;

        $runview_temperature = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $temperature;
    }

    // Getting Precipitation Data
    public function getPrecipitation($station)
    {
        $precipitation = null;

        $time = Carbon::now()->subHour(1);

        $runview_precipitation = runview::where('station', $station)
            ->where('variable', 'Precipitation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_precipitation !== null) {
            $precipitation = $runview_precipitation
                ->data()
                ->select(DB::raw('HOUR(time) as time'), DB::raw('SUM(value) as value'))
                ->where('time', '>=', $time)
                ->groupBy('time')
                ->orderBy('time', 'desc')
                ->first();
        }

        return $precipitation;
    }

    // Getting Precipitation Data - CURW DB Version
    public function getPrecipitationCurw($station)
    {
        $precipitation = null;

        $time = Carbon::now()->subHour(1);

        $runview_precipitation = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'Precipitation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_precipitation !== null) {
            $precipitation = $runview_precipitation
                ->data()
                ->select(DB::raw('HOUR(time) as time'), DB::raw('SUM(value) as value'))
                ->where('time', '>=', $time)
                ->groupBy('time')
                ->orderBy('time', 'desc')
                ->first();
        }

        return $precipitation;
    }

    // Getting Temperature Live Once
    public function getTemperatureOnce($station)
    {
        $temperature = null;

        $runview_temperature = runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }
        $temperature['time'] = strtotime($temperature['time']) * 1000;

        return $temperature;
    }

    // Getting Temperature Live Once - CURW DB Version
    public function getTemperatureOnceCurw($station)
    {
        $temperature = null;

        $runview_temperature = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }
        $temperature['time'] = strtotime($temperature['time']) * 1000;

        return $temperature;
    }

    // Getting WindSpeed Data
    public function getWindSpeed($station)
    {
        $windspeed = null;

        $runview_windspeed = runview::where('station', $station)
            ->where('variable', 'WindSpeed')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windspeed !== null) {
            $windspeed = $runview_windspeed
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $windspeed;
    }

    // Getting WindSpeed Data - CURW DB Version
    public function getWindSpeedCurw($station)
    {
        $windspeed = null;

        $runview_windspeed = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'WindSpeed')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windspeed !== null) {
            $windspeed = $runview_windspeed
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $windspeed;
    }

    // Getting WindGust Data
    public function getWindGust($station)
    {
        $windgust = null;

        $runview_windgust = runview::where('station', $station)
            ->where('variable', 'WindGust')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windgust !== null) {
            $windgust = $runview_windgust
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $windgust;
    }

    // Getting WindGust Data - CURW DB Version
    public function getWindGustCurw($station)
    {
        $windgust = null;

        $runview_windgust = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'WindGust')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windgust !== null) {
            $windgust = $runview_windgust
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $windgust;
    }

    // Getting SolarRadiation Data
    public function getSolarRadiation($station)
    {
        $solarradiation = null;

        $runview_solarradiation = runview::where('station', $station)
            ->where('variable', 'SolarRadiation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_solarradiation !== null) {
            $solarradiation = $runview_solarradiation
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $solarradiation;
    }

    // Getting SolarRadiation Data - CURW DB Version
    public function getSolarRadiationCurw($station)
    {
        set_time_limit(0);
        $solarradiation = null;

        $runview_solarradiation = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'SolarRadiation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_solarradiation !== null) {
            $solarradiation = $runview_solarradiation
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $solarradiation;
    }

    // Getting WindDirection Data
    public function getWindDirection($station)
    {
        set_time_limit(0);
        $winddirection = null;

        $runview_winddirection = runview::where('station', $station)
            ->where('variable', 'WindDirection')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_winddirection !== null) {
            $winddirection = $runview_winddirection
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $winddirection;
    }

    // Getting WindDirection Data - CURW DB Version
    public function getWindDirectionCurw($station)
    {
        set_time_limit(0);
        $winddirection = null;

        $runview_winddirection = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'WindDirection')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_winddirection !== null) {
            $winddirection = $runview_winddirection
                ->data()
                ->select(['time', 'value'])
                ->orderBy('time', 'desc')
                ->first();
        }

        return $winddirection;
    }

    // Getting Temperature Real Time
    public function getTemperatureLive($station)
    {
        set_time_limit(0);
        $temperature = null;
        $current_date = null;
        $values = null;

        date_default_timezone_set('Asia/Colombo');

        $current_date = Carbon::today();

        $runview_temperature = runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $values = $runview_temperature
                ->data()
                ->where('time', '>', $current_date)
                ->select(['time', 'value'])
                ->get();
        }

        if ($values !== null) {
            foreach ($values as $key => $value) {
                $temperature[$key]['time'] = strtotime($value['time']) * 1000;
                $temperature[$key]['value'] = $value['value'];
            }
        }

        return $temperature;
    }

    // Getting Temperature Real Time - CURW DB Version
    public function getTemperatureLiveCurw($station)
    {
        set_time_limit(0);
        $temperature = null;
        $current_date = null;
        $values = null;

        date_default_timezone_set('Asia/Colombo');

        $current_date = Carbon::today();

        $runview_temperature = \App\Models\RunView\runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $values = $runview_temperature
                ->data()
                ->where('time', '>', $current_date)
                ->select(['time', 'value'])
                ->get();
        }

        if ($values !== null) {
            foreach ($values as $key => $value) {
                $temperature[$key]['time'] = strtotime($value['time']) * 1000;
                $temperature[$key]['value'] = $value['value'];
            }
        }

        return $temperature;
    }

    // Sending json response of all data
    public function getLiveData($station)
    {
        set_time_limit(0);
        $temperature = null;
        $windspeed = null;
        $windgust = null;
        $precipitations = null;
        $humidity = null;
        $solar = null;
        $winddirection = null;

        $today = Carbon::today();

        // Getting Temperature
        $runview_temperature = runview::where('station', $station)
            ->where('variable', 'Temperature')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindSpeed
        $runview_windspeed = runview::where('station', $station)
            ->where('variable', 'WindSpeed')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windspeed !== null) {
            $windspeed = $runview_windspeed
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindGust
        $runview_windgust = runview::where('station', $station)
            ->where('variable', 'WindGust')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_windgust !== null) {
            $windgust = $runview_windgust
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting Precipitation
        $runview_precipitation = runview::where('station', $station)
            ->where('variable', 'Precipitation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_precipitation !== null) {
            $precipitations = $runview_precipitation
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting Humidity
        $runview_humidity = runview::where('station', $station)
            ->where('variable', 'Humidity')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_humidity !== null) {
            $humidity = $runview_humidity
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting SolarRadiation
        $runview_solar = runview::where('station', $station)
            ->where('variable', 'SolarRadiation')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_solar !== null) {
            $solar = $runview_solar
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindDirection
        $winddirections = null;
        $runview_winddirection = runview::where('station', $station)
            ->where('variable', 'WindDirection')
            ->where('source', 'WeatherStation')
            ->first();
        if ($runview_winddirection !== null) {
            $winddirections = $runview_winddirection
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Creating json response
        $values = array();

        foreach ($precipitations as $key => $preci) {
            $values['xData'][] = strtotime($preci['time']) * 1000;
            $values['min_date'] = strtotime(Carbon::today()) * 1000;
            $values['max_date'] = strtotime(Carbon::today()->addHours(23)) * 1000;

            // Temperature
            if ($temperature !== null) {
                $values['datasets'][0]['name'] = 'Temperature';
                $values['datasets'][0]['data'][] = round((float)$temperature[$key]['value'], 1);
                $values['datasets'][0]['unit'] = '°C';
                $values['datasets'][0]['type'] = 'line';
                $values['datasets'][0]['valueDecimals'] = '1';
            }

            // Precipitation
            $values['datasets'][1]['name'] = 'Precipitation';
            if (isset($preci['value'])) {
                $values['datasets'][1]['data'][] = round((float)$preci['value'], 1);
            } else {
                $values['datasets'][1]['data'][] = 0.0;
            }
            $values['datasets'][1]['unit'] = 'mm';
            $values['datasets'][1]['type'] = 'column';
            $values['datasets'][1]['valueDecimals'] = '2';

            // WindSpeed
            if ($windspeed !== null) {
                $values['datasets'][2]['name'] = 'Wind Speed';
                if (isset($windspeed[$key]['value'])) {
                    $values['datasets'][2]['data'][] = round((float)$windspeed[$key]['value'], 1);
                } else {
                    $values['datasets'][2]['data'][] = 0.0;
                }
                $values['datasets'][2]['unit'] = 'm/s';
                $values['datasets'][2]['type'] = 'scatter';
                $values['datasets'][2]['valueDecimals'] = '1';
            }

            // WindGust
            if ($windgust !== null) {
                $values['datasets'][3]['name'] = 'Wind Gust';
                if (isset($windgust[$key]['value'])) {
                    $values['datasets'][3]['data'][] = round((float)$windgust[$key]['value'], 1);
                } else {
                    $values['datasets'][3]['data'][] = 0.0;
                }
                $values['datasets'][3]['unit'] = 'm/s';
                $values['datasets'][3]['type'] = 'scatter';
                $values['datasets'][3]['valueDecimals'] = '1';
            }

            if ($winddirections !== null) {
                $values['datasets'][4]['name'] = 'Wind Direction';
                if (isset($winddirections[$key]['value'])) {
                    $values['datasets'][4]['data'][] = round((float)$winddirections[$key]['value'], 1);
                } else {
                    $values['datasets'][4]['data'][] = 0.0;
                }
                $values['datasets'][4]['unit'] = '°';
                $values['datasets'][4]['type'] = 'scatter';
                $values['datasets'][4]['valueDecimals'] = '2';
            }

            #############################################

            // Humidity
            if ($humidity !== null) {
                $values['datasets'][5]['name'] = 'Humidity';
                if (isset($humidity[$key]['value'])) {
                    $values['datasets'][5]['data'][] = (int)$humidity[$key]['value'];
                } else {
                    $values['datasets'][5]['data'][] = 0;
                }
                $values['datasets'][5]['unit'] = '%';
                $values['datasets'][5]['type'] = 'line';
                $values['datasets'][5]['valueDecimals'] = '0';
            }

            // SolarRadiation
            if ($solar !== null) {
                $values['datasets'][6]['name'] = 'Solar Radiation';
                if (isset($solar[$key]['value'])) {
                    $values['datasets'][6]['data'][] = (int)$solar[$key]['value'];
                } else {
                    $values['datasets'][6]['data'][] = 0;
                }
                $values['datasets'][6]['unit'] = 'W/m2';
                $values['datasets'][6]['type'] = 'line';
                $values['datasets'][6]['valueDecimals'] = '2';
            }

        }
//        dd($values);
        return response($values);
    }

    // Sending json response of all data - CURW DB Version
    public function getLiveDataCurw($station)
    {
        set_time_limit(0);
        $temperature = null;
        $windspeed = null;
        $windgust = null;
        $precipitations = null;
        $humidity = null;
        $solar = null;
        $winddirection = null;

        $today = Carbon::today();

        // Getting Temperature
        if ($station == 'Orugodawatta') {
            $runview_temperature = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Temperature')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_temperature = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Temperature')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_temperature !== null) {
            $temperature = $runview_temperature
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindSpeed
        if ($station == 'Orugodawatta') {
            $runview_windspeed = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindSpeed')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_windspeed = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindSpeed')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_windspeed !== null) {
            $windspeed = $runview_windspeed
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindGust
        if ($station == 'Orugodawatta') {
            $runview_windgust = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindGust')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_windgust = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindGust')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_windgust !== null) {
            $windgust = $runview_windgust
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting Precipitation
        if ($station == 'Orugodawatta') {
            $runview_precipitation = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_precipitation = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_precipitation !== null) {
            $precipitations = $runview_precipitation
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting Humidity
        if ($station == 'Orugodawatta') {
            $runview_humidity = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Humidity')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_humidity = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'Humidity')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_humidity !== null) {
            $humidity = $runview_humidity
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting SolarRadiation
        if ($station == 'Orugodawatta') {
            $runview_solar = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'SolarRadiation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_solar = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'SolarRadiation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_solar !== null) {
            $solar = $runview_solar
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Getting WindDirection
        $winddirections = null;
        if ($station == 'Orugodawatta') {
            $runview_winddirection = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindDirection')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $runview_winddirection = \App\Models\RunView\runview::where('station', $station)
                ->where('variable', 'WindDirection')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }
        if ($runview_winddirection !== null) {
            $winddirections = $runview_winddirection
                ->data()
                ->where('time', '>=', $today)
                ->select(['time', 'value'])
                ->get();
        }

        // Creating json response
        $values = array();

        foreach ($precipitations as $key => $preci) {
            $values['xData'][] = strtotime($preci['time']) * 1000;
            $values['min_date'] = strtotime(Carbon::today()) * 1000;
            $values['max_date'] = strtotime(Carbon::today()->addHours(11)) * 1000;

            // Temperature
            if ($temperature !== null) {
                $values['datasets'][0]['name'] = 'Temperature';
                $values['datasets'][0]['data'][] = round((float)$temperature[$key]['value'], 1);
                $values['datasets'][0]['unit'] = '°C';
                $values['datasets'][0]['type'] = 'line';
                $values['datasets'][0]['valueDecimals'] = '1';
            }

            // Precipitation
            $values['datasets'][1]['name'] = 'Precipitation';
            if (isset($preci['value'])) {
                $values['datasets'][1]['data'][] = round((float)$preci['value'], 1);
            } else {
                $values['datasets'][1]['data'][] = 0.0;
            }
            $values['datasets'][1]['unit'] = 'mm';
            $values['datasets'][1]['type'] = 'column';
            $values['datasets'][1]['valueDecimals'] = '2';

            // WindSpeed
            if ($windspeed !== null) {
                $values['datasets'][2]['name'] = 'Wind Speed';
                if (isset($windspeed[$key]['value'])) {
                    $values['datasets'][2]['data'][] = round((float)$windspeed[$key]['value'], 1);
                } else {
                    $values['datasets'][2]['data'][] = 0.0;
                }
                $values['datasets'][2]['unit'] = 'm/s';
                $values['datasets'][2]['type'] = 'scatter';
                $values['datasets'][2]['valueDecimals'] = '1';
            }

            // WindGust
            if ($windgust !== null) {
                $values['datasets'][3]['name'] = 'Wind Gust';
                if (isset($windgust[$key]['value'])) {
                    $values['datasets'][3]['data'][] = round((float)$windgust[$key]['value'], 1);
                } else {
                    $values['datasets'][3]['data'][] = 0.0;
                }
                $values['datasets'][3]['unit'] = 'm/s';
                $values['datasets'][3]['type'] = 'scatter';
                $values['datasets'][3]['valueDecimals'] = '1';
            }

            if ($winddirections !== null) {
                $values['datasets'][4]['name'] = 'Wind Direction';
                if (isset($winddirections[$key]['value'])) {
                    $values['datasets'][4]['data'][] = round((float)$winddirections[$key]['value'], 1);
                } else {
                    $values['datasets'][4]['data'][] = 0.0;
                }
                $values['datasets'][4]['unit'] = '°';
                $values['datasets'][4]['type'] = 'scatter';
                $values['datasets'][4]['valueDecimals'] = '2';
            }

            #############################################

            // Humidity
            if ($humidity !== null) {
                $values['datasets'][5]['name'] = 'Humidity';
                if (isset($humidity[$key]['value'])) {
                    $values['datasets'][5]['data'][] = (int)$humidity[$key]['value'];
                } else {
                    $values['datasets'][5]['data'][] = 0;
                }
                $values['datasets'][5]['unit'] = '%';
                $values['datasets'][5]['type'] = 'line';
                $values['datasets'][5]['valueDecimals'] = '0';
            }

            // SolarRadiation
            if ($solar !== null) {
                $values['datasets'][6]['name'] = 'Solar Radiation';
                if (isset($solar[$key]['value'])) {
                    $values['datasets'][6]['data'][] = (int)$solar[$key]['value'];
                } else {
                    $values['datasets'][6]['data'][] = 0;
                }
                $values['datasets'][6]['unit'] = 'W/m2';
                $values['datasets'][6]['type'] = 'line';
                $values['datasets'][6]['valueDecimals'] = '2';
            }

        }
//        dd($values);
        return response($values);
    }

    // Station status reports
    public function status()
    {
        set_time_limit(0);
        $status = null;
        $result = null;
        $color = null;
        $last_updated = null;
        $values = null;
        $time = null;
        $temperature = null;
        $precipitation = null;
        $result_prep_3h = null;
        $result_prep_24h = null;
        $result_preci = null;

        date_default_timezone_set('Asia/Colombo');

        $date = Carbon::today()->format('Y-m-d');

        $stations = Station::select('name')->get();

        if ($stations->isNotEmpty()) {
            foreach ($stations as $key => $station) {
                $color = null;

                // Getting runview
//                if ($station->name == 'Kottawa North Dharmapala School' || $station->name == 'Hingurana') {
                if ($station->name == 'Kottawa North Dharmapala School') {
                    $runview_preci = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->whereIn('name', ['Leecom', 'A&T Labs'])
                        ->where('start_date', '!=', null)
                        ->first();
                } else {
                    $runview_preci = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('start_date', '!=', null)
                        ->first();
                }

                if ($runview_preci !== null) {
                    $result_preci = $runview_preci
                        ->data()
                        ->select(['time', 'value'])
                        ->orderBy('time', 'desc')
                        ->first();

                    // Getting Precipitation
//                    if ($station->name == 'Kottawa North Dharmapala School' || $station->name == 'Hingurana') {
                    if ($station->name == 'Kottawa North Dharmapala School') {
                        $runview_prep = runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->whereIn('name', ['Leecom', 'A&T Labs'])
                            ->first();
                    } else {
                        $runview_prep = runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->first();
                    }

                    if ($runview_prep !== null) {
                        $result_prep = $runview_prep
                            ->data()
                            ->select(['time', 'value'])
                            ->orderBy('time', 'desc')
                            ->first();

                        $result_prep_3hs = $runview_prep
                            ->data()
//                            ->select([DB::raw('value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(3))
//                            ->groupBy('value')
                            ->orderBy('time', 'desc')
                            ->first();

                        $result_prep_24hs = $runview_prep
                            ->data()
//                            ->select([DB::raw('MAX(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(24))
//                            ->groupBy('value')
                            ->orderBy('time', 'desc')
                            ->first();
                    }

                    $result_prep_3h = null;
                    $result_prep_24h = null;

                    $result_prep_3h = $result_prep_3hs['value'];
                    $result_prep_24h = $result_prep_24hs['value'];

//                    foreach ($result_prep_3hs as $result_3h) {
//                        $result_prep_3h += $result_3h->value;
//                    }
//
//                    foreach ($result_prep_24hs as $result_24h) {
//                        $result_prep_24h += $result_24h->value;
//                    }


                    $temperature = null;
                    if ($this->getTemperatureOnce($station->name) !== null) {
                        if (isset($this->getTemperatureOnce($station->name)->value)) {
                            $temperature = round($this->getTemperatureOnce($station->name)->value, 1);
                        }
                    }
                    $precipitation = round($result_prep['value'], 1);
                    $precipitation_3h = round($result_prep_3h, 1);
                    $precipitation_24h = round($result_prep_24h, 1);


                    if ($runview_preci->name === 'CUrW IoT') {
                        if (Carbon::parse($result_preci['time'])->diffInMinutes(Carbon::now()) <= 30) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    } else {
                        if (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 3) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    }

                    $last_updated = Carbon::parse($result_preci['time'])->diffForHumans();

                    $values[] = array('name' => $station->name, 'color' => $color, 'last_updated' => $last_updated, 'source' => $runview_preci->name, 'precipitation' => $precipitation, 'temperature' => $temperature, 'precipitation_3h' => $precipitation_3h, 'precipitation_24h' => $precipitation_24h);
                }
            }
            return view('frontend.observations.status')->with(['stations' => $values, 'date' => $date]);
        }

        return false;
    }

    public function statusIntern()
    {
        $status = null;
        $result = null;
        $color = null;
        $last_updated = null;
        $values = null;
        $time = null;
        $temperature = null;
        $precipitation = null;
        $result_prep_1h = null;
        $result_prep_3h = null;
        $result_prep_24h = null;
        $result_prep_24hs = null;
        $result_prep_3hs = null;
        $result_prep_1hs = null;
        $result_preci = null;
        $result_prep = null;
        set_time_limit(0);

        date_default_timezone_set('Asia/Colombo');

        $date = Carbon::today()->format('Y-m-d');

        $stations = Station::select('name')->get();

        if ($stations->isNotEmpty()) {
            foreach ($stations as $key => $station) {
                $color = null;

                // Getting Precipitation
                if ($station->name == 'Orugodawatta') {
                    $runview_preci = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('name', 'CUrW IoT')
                        ->where('start_date', '!=', null)
                        ->first();

//                    dd($runview_preci);
                } elseif ($station->name == 'Kottawa North Dharmapala School') {
                    $runview_preci = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('name', 'Leecom')
                        ->where('start_date', '!=', null)
                        ->first();
                }
//                elseif ($station->name == 'Hingurana') {
//                    $runview_preci = \App\Models\RunView\runview::where('station', $station->name)
//                        ->where('variable', 'Precipitation')
//                        ->where('source', 'WeatherStation')
//                        ->where('name', 'A&T Labs')
//                        ->where('start_date', '!=', null)
//                        ->first();
//
////                    dd($runview_preci);
//                }
                else {
                    $runview_preci = runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('start_date', '!=', null)
                        ->first();
                }

                if ($runview_preci !== null) {
                    $result_preci = $runview_preci
                        ->data()
                        ->select(['time', 'value'])
                        ->orderBy('time', 'desc')
                        ->first();

                    // Getting Precipitation
//                    if ($station->name == 'Hingurana') {
//                        $runview_prep = \App\Models\RunView\runview::where('station', $station->name)
//                            ->where('variable', 'Precipitation')
//                            ->where('source', 'WeatherStation')
//                            ->where('name', 'A&T Labs')
//                            ->first();
//
////                    dd($runview_preci);
//                    }
//                    elseif ($station->name == 'Orugodawatta') {
                    if ($station->name == 'Orugodawatta') {
                        $runview_prep = runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->where('name', 'CUrW IoT')
                            ->first();

//                    dd($runview_preci);
                    } elseif ($station->name == 'Kottawa North Dharmapala School') {
                        $runview_prep = runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->where('name', 'Leecom')
                            ->first();
                    } else {
                        $runview_prep = runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->first();
                    }

                    if ($runview_prep !== null) {
                        $result_prep = $runview_prep
                            ->data()
                            ->select(['time', 'value'])
                            ->orderBy('time', 'desc')
                            ->first();

                        $result_prep_1hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(1))
                            ->groupBy('value')
                            ->get();

                        $result_prep_3hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(3))
                            ->groupBy('value')
                            ->get();

                        $result_prep_24hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(24))
                            ->groupBy('value')
                            ->get();
                    }

                    $result_prep_1h = null;
                    $result_prep_3h = null;
                    $result_prep_24h = null;

                    foreach ($result_prep_1hs as $result_1h) {
                        $result_prep_1h += $result_1h->value;
                    }

                    foreach ($result_prep_3hs as $result_3h) {
                        $result_prep_3h += $result_3h->value;
                    }

                    foreach ($result_prep_24hs as $result_24h) {
                        $result_prep_24h += $result_24h->value;
                    }
//                    if ($station->name == 'Orugodawatta') {
////                        dd($result_prep_24h);
//                    }
                    $temperature = null;
                    if ($this->getTemperatureOnceCurw($station->name) !== null) {
                        if (isset($this->getTemperatureOnceCurw($station->name)->value)) {
                            $temperature = round($this->getTemperatureOnceCurw($station->name)->value, 1);
                        }
                    }
                    $precipitation = round($result_prep['value'], 1);
                    $precipitation_1h = round($result_prep_1h, 1);
                    $precipitation_3h = round($result_prep_3h, 1);
                    $precipitation_24h = round($result_prep_24h, 1);

                    if ($runview_preci['name'] === 'CUrW IoT') {
                        if (Carbon::parse($result_preci['time'])->diffInMinutes(Carbon::now()) <= 30) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    } else {
                        if (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 3) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    }

                    $last_updated = Carbon::parse($result_preci['time'])->diffForHumans();

                    $values[] = array('name' => $station->name, 'color' => $color, 'last_updated' => $last_updated, 'source' => $runview_preci->name, 'precipitation' => $precipitation, 'temperature' => $temperature, 'precipitation_1h' => $precipitation_1h, 'precipitation_3h' => $precipitation_3h, 'precipitation_24h' => $precipitation_24h);
                }
            }

            return view('frontend.observations.internal-status')->with(['stations' => $values, 'date' => $date]);
        }

        return false;
    }

    // Station status reports - CURW DB Version
    public function statusCurw()
    {
        $status = null;
        $result = null;
        $color = null;
        $last_updated = null;
        $values = null;
        $time = null;
        $temperature = null;
        $precipitation = null;
        $result_prep_1h = null;
        $result_prep_3h = null;
        $result_prep_24h = null;
        $result_prep_24hs = null;
        $result_prep_3hs = null;
        $result_prep_1hs = null;
        $result_preci = null;
        $result_prep = null;
        set_time_limit(0);

        date_default_timezone_set('Asia/Colombo');

        $date = Carbon::today()->format('Y-m-d');

        $stations = Station::select('name')->get();

        if ($stations->isNotEmpty()) {
            foreach ($stations as $key => $station) {
                $color = null;

                // Getting Precipitation
                if ($station->name == 'Orugodawatta') {
                    $runview_preci = \App\Models\RunView\runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('name', 'CUrW IoT')
                        ->where('start_date', '!=', null)
                        ->first();

//                    dd($runview_preci);
                }
//                elseif ($station->name == 'Hingurana') {
//                    $runview_preci = \App\Models\RunView\runview::where('station', $station->name)
//                        ->where('variable', 'Precipitation')
//                        ->where('source', 'WeatherStation')
//                        ->where('name', 'A&T Labs')
//                        ->where('start_date', '!=', null)
//                        ->first();
//
////                    dd($runview_preci);
//                }
                else {
                    $runview_preci = \App\Models\RunView\runview::where('station', $station->name)
                        ->where('variable', 'Precipitation')
                        ->where('source', 'WeatherStation')
                        ->where('start_date', '!=', null)
                        ->first();
                }

                if ($runview_preci !== null) {
                    $result_preci = $runview_preci
                        ->data()
                        ->select(['time', 'value'])
                        ->orderBy('time', 'desc')
                        ->first();

                    // Getting Precipitation
//                    if ($station->name == 'Hingurana') {
//                        $runview_prep = \App\Models\RunView\runview::where('station', $station->name)
//                            ->where('variable', 'Precipitation')
//                            ->where('source', 'WeatherStation')
//                            ->where('name', 'A&T Labs')
//                            ->first();
//
////                    dd($runview_preci);
//                    }
//                    elseif ($station->name == 'Orugodawatta') {
                    if ($station->name == 'Orugodawatta') {
                        $runview_prep = \App\Models\RunView\runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->where('name', 'CUrW IoT')
                            ->first();

//                    dd($runview_preci);
                    } else {
                        $runview_prep = \App\Models\RunView\runview::where('station', $station->name)
                            ->where('variable', 'Precipitation')
                            ->where('source', 'WeatherStation')
                            ->first();
                    }

                    if ($runview_prep !== null) {
                        $result_prep = $runview_prep
                            ->data()
                            ->select(['time', 'value'])
                            ->orderBy('time', 'desc')
                            ->first();

                        $result_prep_1hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(1))
                            ->groupBy('value')
                            ->get();

                        $result_prep_3hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(3))
                            ->groupBy('value')
                            ->get();

                        $result_prep_24hs = $runview_prep
                            ->data()
                            ->select([DB::raw('SUM(value) as value')])
                            ->where('time', '>=', Carbon::parse($runview_preci->time)->subHours(24))
                            ->groupBy('value')
                            ->get();
                    }

                    $result_prep_1h = null;
                    $result_prep_3h = null;
                    $result_prep_24h = null;

                    foreach ($result_prep_1hs as $result_1h) {
                        $result_prep_1h += $result_1h->value;
                    }

                    foreach ($result_prep_3hs as $result_3h) {
                        $result_prep_3h += $result_3h->value;
                    }

                    foreach ($result_prep_24hs as $result_24h) {
                        $result_prep_24h += $result_24h->value;
                    }
//                    if ($station->name == 'Orugodawatta') {
////                        dd($result_prep_24h);
//                    }
                    $temperature = null;
                    if ($this->getTemperatureOnceCurw($station->name) !== null) {
                        if (isset($this->getTemperatureOnceCurw($station->name)->value)) {
                            $temperature = round($this->getTemperatureOnceCurw($station->name)->value, 1);
                        }
                    }
                    $precipitation = round($result_prep['value'], 1);
                    $precipitation_1h = round($result_prep_1h, 1);
                    $precipitation_3h = round($result_prep_3h, 1);
                    $precipitation_24h = round($result_prep_24h, 1);

                    if ($runview_preci['name'] === 'CUrW IoT') {
                        if (Carbon::parse($result_preci['time'])->diffInMinutes(Carbon::now()) <= 30) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    } else {
                        if (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 1) {
                            $color = 'green';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) <= 3) {
                            $color = 'orange';
                        } elseif (Carbon::parse($result_preci['time'])->diffInHours(Carbon::now()) < 6) {
                            $color = 'orange';
                        } else {
                            $color = 'red';
                        }
                    }

                    $last_updated = Carbon::parse($result_preci['time'])->diffForHumans();

                    $values[] = array('name' => $station->name, 'color' => $color, 'last_updated' => $last_updated, 'source' => $runview_preci->name, 'precipitation' => $precipitation, 'temperature' => $temperature, 'precipitation_1h' => $precipitation_1h, 'precipitation_3h' => $precipitation_3h, 'precipitation_24h' => $precipitation_24h);
                }
            }

            return view('frontend.observations.status-test')->with(['stations' => $values, 'date' => $date]);
        }

        return false;
    }

    /*
     * Water level stations
     * */
    // Status
    public function statusWL()
    {
        $values = null;

        $runs = runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->get();

        if ($runs->isNotEmpty()) {
            foreach ($runs as $key => $run) {
                $run_data = $run
                    ->data()
                    ->select(['time', 'value'])
                    ->orderBy('time', 'desc')
                    ->first();

                if (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 1) {
                    $color = 'green';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 3) {
                    $color = 'orange';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) < 6) {
                    $color = 'orange';
                } else {
                    $color = 'red';
                }

                $values[] = array('name' => $run->station, 'color' => $color, 'last_updated' => Carbon::parse($run_data['time'])->diffForHumans(), 'source' => $run->name, 'water_level' => round($run_data['value'], 2) . ' m');
//                $values[] = $run_data;
            }

//            dd($values);

            return view('frontend.observations.water-level-status')->with(['stations' => $values]);
        } else {
            echo 'something went wrong, please contact the developer, Thank you!';
        }

    }

    // Status CURW
    public function statusCurwWL()
    {
        set_time_limit(0);

        $values = null;
        $mean_3h = null;
        $mean_6h = null;
        $mean_12h = null;

        $date = Carbon::today()->format('Y-m-d');

        $runs = \App\Models\RunView\runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->orderBy('start_date', 'asc')->get();

        if ($runs->isNotEmpty()) {
            foreach ($runs as $key => $run) {
                $run_data = $run
                    ->data()
                    ->select(['time', 'value'])
                    ->orderBy('time', 'desc')
                    ->first();

                // getting max value
                $max_run_data = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(1))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                $max_3h = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(3))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                $max_6h = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(6))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                $max_12h = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(12))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                // getting min value
                $min_3h = $run
                    ->data()
                    ->selectRaw('MIN(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(3))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'asc')
                    ->first();

                $min_6h = $run
                    ->data()
                    ->selectRaw('MIN(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(6))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'asc')
                    ->first();

                $min_12h = $run
                    ->data()
                    ->selectRaw('MIN(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(12))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'asc')
                    ->first();

                // getting mean value
                $mean_3h_data = $run
                    ->data()
                    ->where('time', '>=', Carbon::now()->subHours(3))
                    ->pluck('value')
                    ->toArray();

                $mean_6h_data = $run
                    ->data()
                    ->where('time', '>=', Carbon::now()->subHours(6))
                    ->pluck('value')
                    ->toArray();

                $mean_12h_data = $run
                    ->data()
                    ->where('time', '>=', Carbon::now()->subHours(12))
                    ->pluck('value')
                    ->toArray();

                if (count($mean_3h_data) > 0) {
                    $mean_3h = array_sum($mean_3h_data) / count($mean_3h_data);
                }
                if (count($mean_6h_data) > 0) {
                    $mean_6h = array_sum($mean_6h_data) / count($mean_6h_data);
                }
                if (count($mean_12h_data) > 0) {
                    $mean_12h = array_sum($mean_12h_data) / count($mean_12h_data);
                }

                if (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 1) {
                    $color = 'green';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 3) {
                    $color = 'orange';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) < 6) {
                    $color = 'orange';
                } else {
                    $color = 'red';
                }

                // Setting station alert level colors
                $status = 'Normal';
                $normal = '<span style="color: rgba(0,118,140,0.79);">Status: Normal</span>';
                $alert = '<span style="color: rgba(134,140,5,0.79);">Status: Alert</span>';
                $flood = '<span style="color: rgba(140,17,0,0.79);">Status: Flood</span>';

                if ($run->station == 'Diyasaru Uyana') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Ingurukade') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Leecom WL Guage') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellampitiya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellawatta') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Yakbedda') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                $values[] = array(
                    'name' => $run->station,
                    'color' => $color,
                    'last_updated' => Carbon::parse($run_data['time'])->diffForHumans(),
                    'source' => $run->name,
                    'min_3h' => round($min_3h['value'], 2),
                    'min_6h' => round($min_6h['value'], 2),
                    'min_12h' => round($min_12h['value'], 2),
                    'max_3h' => round($max_3h['value'], 2),
                    'max_6h' => round($max_6h['value'], 2),
                    'max_12h' => round($max_12h['value'], 2),
                    'mean_3h' => round($mean_3h, 2),
                    'mean_6h' => round($mean_6h, 2),
                    'mean_12h' => round($mean_12h, 2),
                    'water_level' => round($run_data['value'], 2) . ' m', 'status' => $status
                );
            }

            $values = array_filter($values, function ($station) {
                return $station['color'] === 'green';
            });

//            dd($values);

//            dd($values);

            return view('frontend.observations.water-level-status-curw')->with(['stations' => $values, 'date' => $date]);
        } else {
            echo 'something went wrong, please contact the developer, Thank you!';
        }

    }

    // Status CURW WLR
    public function statusCurwWLR()
    {
        set_time_limit(0);

        $values = null;

        $date = Carbon::today()->format('Y-m-d');

        $runs = \App\Models\RunView\runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->orderBy('start_date', 'asc')->get();

        if ($runs->isNotEmpty()) {
            foreach ($runs as $key => $run) {
                $run_data = $run
                    ->data()
                    ->select(['time', 'value'])
                    ->orderBy('time', 'desc')
                    ->first();

                $max_run_data = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(1))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                if (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 1) {
                    $color = 'green';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 3) {
                    $color = 'orange';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) < 6) {
                    $color = 'orange';
                } else {
                    $color = 'red';
                }

                // Setting station alert level colors
                $status = 'Normal';
                $rainfall = 'IBATTARA2';
                $normal = '<span style="color: rgba(0,118,140,0.79);">Status: Normal</span>';
                $alert = '<span style="color: rgba(134,140,5,0.79);">Status: Alert</span>';
                $flood = '<span style="color: rgba(140,17,0,0.79);">Status: Flood</span>';

                if ($run->station == 'Diyasaru Uyana') {
                    $stations[$key]['name'] = $run->station;
                    $stations[$key]['rainfall'] = 'IBATTARA2';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Ingurukade') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'Kotikawatta';
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Diyasaru Uyana') {
//                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'IBATTARA2';
//                    if ($max_run_data['value'] >= 1) {
//                        $status = $alert;
//                    } elseif ($max_run_data['value'] >= 1.2) {
//                        $status = $flood;
//                    } else {
//                        $status = $normal;
//                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'IBATTARA2';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

//                if ($run->station == 'Janakala Kendraya') {
//                    $stations[$key]['name'] = $run->station;
//                    $stations[$key]['rainfall'] = 'IBATTARA2';
//                    if ($max_run_data['value'] >= 1.7) {
//                        $status = $alert;
//                    } elseif ($max_run_data['value'] >= 2) {
//                        $status = $flood;
//                    } else {
//                        $status = $normal;
//                    }
//                }

                if ($run->station == 'Leecom WL Guage') {
                    $stations[$key]['name'] = 'Diyasaru Gate Upstream';
                    $rainfall = 'IBATTARA2';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellampitiya') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'Kotikawatta';
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellawatta') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'Kottawa North Dharmapala School';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Yakbedda') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'Kotikawatta';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Ranwala Bridge') {
                    $stations[$key]['name'] = $run->station;
                    $rainfall = 'Urumewella';
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                $values[] = array('name' => $run->station, 'color' => $color, 'last_updated' => Carbon::parse($run_data['time'])->diffForHumans(), 'source' => $run->name, 'water_level' => round($run_data['value'], 2) . ' m', 'status' => $status, 'rainfall' => $rainfall);
//                $values[] = $run_data;
            }

//            dd($values);

//            dd($values);
            return view('frontend.observations.stations-status-curw')->with(['stations' => $values, 'date' => $date]);
        } else {
            echo 'something went wrong, please contact the developer, Thank you!';
        }
    }
}
