<?php

namespace App\Http\Controllers\Frontend\Screens;

use DB;
use DateTime;
use Carbon\Carbon;
use App\Models\RunView\runview;
use App\Models\IOT\station;
use App\Http\Controllers\Controller;

use App\Http\Controllers\Frontend\Observations\ObserveController;
use App\Models\FCT\runview as RunviewFct;
use App\Models\FCT\data as DataFct;
use App\Models\FCT\station as StationFct;

class ScreenController extends Controller
{
    public $ObserveController;

    public function __construct()
    {
        $this->ObserveController = new ObserveController();
    }

    public function sortValues($a, $b)
    {
        //        return $a['time'] <=> $b['time'];
        $t1 = strtotime($a['time']);
        $t2 = strtotime($b['time']);
        return $t1 - $t2;
    }

    public function dataWL($station)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }

        // if current data is null
        if ($values == null) {
            $data_1 = [];
            $data_2 = [];
            $data_3 = [];
            $static_data = [];

            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->where('end_date', '>=', $date_1_start)->first();

            // Getting data from data table
            if ($run_1 !== null) {
                $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_2 !== null) {
                $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_3 !== null) {
                $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            }

            //        if($station == 'Parliament Lake Side'){
            //            dd($run_1);
            //        }

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }

            // Merge static run data
            if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
                $data = array_merge($data_1, $data_2);
                $static_data = array_merge($data, $data_3);
            }

            // Creating data set
            $values = null;
            if ($static_data !== []) {
                foreach ($static_data as $value) {
                    $value['time'] = strtotime($value['time']) * 1000;
                    $values[] = $value;
                }
            }
        }

        return $values;
    }

    public function dataWL150($station)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        // if current data is null
        if ($values == null) {

            $data_1 = [];
            $data_2 = [];
            $data_3 = [];
            $static_data = [];

            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'FLO2D_150')->where('end_date', '>=', $date_1_start)->first();


            // Getting data from data table
            if ($run_1 !== null) {
                $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_2 !== null) {
                $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_3 !== null) {
                $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            }

            //            if($station == 'Kelani Mulla Outfall'){
            //                dd($run_1,$date_1_start, $date_1_end, $data_1);
            //            }

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->orderBy('time', 'asc')->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->get()->toArray();
            }

            // Merge static run data
            if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
                $data = array_merge($data_1, $data_2);
                $static_data = array_merge($data, $data_3);
            }

            // Creating data set
            $values = null;
            if ($static_data !== []) {
                foreach ($static_data as $value) {
                    $value['time'] = strtotime($value['time']) * 1000;
                    $values[] = $value;
                }
            }
        }

        return $values;
    }

    public function dataWL250WI($station)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        // if current data is null
        if ($values == null) {

            $data_1 = [];
            $data_2 = [];
            $data_3 = [];
            $static_data = [];

            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'FLO2D_250_WI')->where('end_date', '>=', $date_1_start)->first();


            // Getting data from data table
            if ($run_1 !== null) {
                $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_2 !== null) {
                $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_3 !== null) {
                $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            }

            //            if($station == 'Kelani Mulla Outfall'){
            //                dd($run_1,$date_1_start, $date_1_end, $data_1);
            //            }

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->orderBy('time', 'asc')->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->get()->toArray();
            }

            // Merge static run data
            if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
                $data = array_merge($data_1, $data_2);
                $static_data = array_merge($data, $data_3);
            }

            // Creating data set
            $values = null;
            if ($static_data !== []) {
                foreach ($static_data as $value) {
                    $value['time'] = strtotime($value['time']) * 1000;
                    $values[] = $value;
                }
            }
        }

        return $values;
    }

    public function dataWL250HOURLY($station)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        // if current data is null
        if ($values == null) {

            $data_1 = [];
            $data_2 = [];
            $data_3 = [];
            $static_data = [];

            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();


            // Getting data from data table
            if ($run_1 !== null) {
                $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_2 !== null) {
                $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_3 !== null) {
                $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            }

            //            if($station == 'Kelani Mulla Outfall'){
            //                dd($run_1,$date_1_start, $date_1_end, $data_1);
            //            }

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->orderBy('time', 'asc')->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->get()->toArray();
            }

            // Merge static run data
            if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
                $data = array_merge($data_1, $data_2);
                $static_data = array_merge($data, $data_3);
            }

            // Creating data set
            $values = null;
            if ($static_data !== []) {
                foreach ($static_data as $value) {
                    $value['time'] = strtotime($value['time']) * 1000;
                    $values[] = $value;
                }
            }
        }

        return $values;
    }

    public function dataWL250HOURLYS($station, $start)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        // if current data is null
        //         if ($values == null) {

        //             $data_1 = [];
        //             $data_2 = [];
        //             $data_3 = [];
        //             $static_data = [];

        //             $current_date = Carbon::yesterday();
        //             $current_date = $current_date->toDateString();

        //             $date = $current_date . ' 00:00:00';

        //             // Creating Dates
        //             $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        //             $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //             $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //             $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //             $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //             $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //             $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        //             // Getting static station runs from run view
        //             $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        //             $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();
        //             $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'hourly_run')->where('end_date', '>=', $date_1_start)->first();


        //             // Getting data from data table
        //             if ($run_1 !== null) {
        //                 $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        //             }
        //             if ($run_2 !== null) {
        //                 $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        //             }
        //             if ($run_3 !== null) {
        //                 $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        //             }

        // //            if($station == 'Kelani Mulla Outfall'){
        // //                dd($run_1,$date_1_start, $date_1_end, $data_1);
        // //            }

        //             // Getting observe station run
        //             $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        //             // Getting obs data from data table
        //             if ($obs_run != null) {
        //                 $obs_data = $obs_run->data()->orderBy('time', 'asc')->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->get()->toArray();
        //             }

        //             // Merge static run data
        //             if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
        //                 $data = array_merge($data_1, $data_2);
        //                 $static_data = array_merge($data, $data_3);
        //             }

        //             // Creating data set
        //             $values = null;
        //             if ($static_data !== []) {
        //                 foreach ($static_data as $value) {
        //                     $value['time'] = strtotime($value['time']) * 1000;
        //                     $values[] = $value;
        //                 }
        //             }
        //         }

        return $values;
    }

    public function dataWLMike($station)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        //dd($run_1, $run_2, $run_3);
        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);
        }

        // Creating data set
        $values = null;
        if ($static_data !== []) {
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }

        // if current data is null
        if ($values == null) {
            $data_1 = [];
            $data_2 = [];
            $data_3 = [];
            $static_data = [];

            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();

            // Getting data from data table
            if ($run_1 !== null) {
                $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_2 !== null) {
                $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            }
            if ($run_3 !== null) {
                $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            }

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->orderBy('time', 'asc')->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->get()->toArray();
            }

            // Merge static run data
            if ($data_1 !== [] || $data_2 !== [] || $data_3 !== []) {
                $data = array_merge($data_1, $data_2);
                $static_data = array_merge($data, $data_3);
            }

            // Creating data set
            $values = null;
            if ($static_data !== []) {
                foreach ($static_data as $value) {
                    $value['time'] = strtotime($value['time']) * 1000;
                    $values[] = $value;
                }
            }
        }

        return $values;
    }

    public function dataWL250Obs($station, $start)
    {
        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->first();

        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        //        $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }

        if ($values == null) {
            $date = Carbon::parse($start)->subDay(1)->format('Y-m-d H:i:s');

            // Creating Dates
            //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
            //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
            //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->first();
            $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->first();
            $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->first();

            // Getting data from data table
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            //        $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

            // Getting observe station run
            $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

            // Getting obs data from data table
            if ($obs_run != null) {
                $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            }

            // Merge static run data
            //        $data_to = array_merge($data_1, $data_today);
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);

            // Creating data set
            $values = null;
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }

        //        dd($values);
        return $values;
    }

    public function dataWL250ObsPublic($station, $start)
    {
        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->first();

        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        //        $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }

        return $values;
    }

    public function dataWL150Obs($station, $start)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];
        $data_today = [];

        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_1 !== null) {
            //            $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }
        //dd($values);
        return $values;
    }

    public function dataWL150ObsPublic($station, $start)
    {
        $data_1 = [];
        $data_2 = [];
        $data_3 = [];
        $static_data = [];
        $data_today = [];

        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('end_date', '>', '2019-01-01 00:00:00')->where('name', 'FLO2D_150')->first();

        // Getting data from data table
        if ($run_1 !== null) {
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_1 !== null) {
            //            $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_2 !== null) {
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        }
        if ($run_3 !== null) {
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        }

        //        if($station == 'Parliament Lake Side'){
        //            dd($run_1);
        //        }

        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }
        //dd($values);
        return $values;
    }

    public function dataWLMikeObs($station, $start)
    {
        $data_today = [];

        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        //dd($run_1, $date_1_start);
        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        //        $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        //dd($data_1);
        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }

        return $values;
    }

    public function dataWLMikeObsPublic($station, $start)
    {
        $data_today = [];

        $date = Carbon::parse($start)->format('Y-m-d H:i:s');

        // Creating Dates
        //        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        //        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        //        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        //        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));
        //        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 3 day', strtotime($date)));
        //        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 3 day', strtotime($date)));

        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        //        $date_to_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        //        $date_to_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_2 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-1-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        $run_3 = Runview::where('variable', 'Waterlevel')->where('type', 'Forecast-2-d')->where('station', $station)->where('name', 'Daily Continuous')->where('source', 'MIKE11')->first();
        //dd($run_1, $date_1_start);
        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        //        $data_today = $run_1->data()->where('time', '<=', $date_to_end)->where('time', '>=', $date_to_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
        //dd($data_1);
        // Getting observe station run
        $obs_run = Runview::where('variable', 'Waterlevel')->where('type', 'Observed')->where('station', $station)->first();

        // Getting obs data from data table
        if ($obs_run != null) {
            $obs_data = $obs_run->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        }

        // Merge static run data
        //        $data_to = array_merge($data_1, $data_today);
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }

        return $values;
    }

    public function discharge($station)
    {

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_2 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->first();
        $run_3 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-3-d-after')->where('station', $station)->where('name', 'cloud-1')->first();

        //        dd($run_1);

        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

        // Merge static run data
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;
            $values[] = $value;
        }

        if ($values == null) {
            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('- 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('- 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('- 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('- 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-0-d')->where('station', $station)->where('name', 'cloud-1')->first();
            $run_2 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-1-d-after')->where('station', $station)->where('name', 'cloud-1')->first();
            $run_3 = Runview::where('variable', 'Discharge')->where('type', 'Forecast-2-d-after')->where('station', $station)->where('name', 'cloud-1')->first();

            // Getting data from data table
            $data_1 = $run_1->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            $data_3 = $run_3->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();

            // Merge static run data
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);

            // Creating data set
            $values = null;
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }

        return $values;
    }

    public function dataPR($station, $source)
    {

        $current_date = Carbon::today();
        $current_date = $current_date->toDateString();

        $date = $current_date . ' 00:00:00';

        // Creating Dates
        $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
        $date_1_start = date('Y-m-d H:i:s', strtotime($date));
        $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
        $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
        $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
        $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
        $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

        // Getting static station runs from run view
        $run_1 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-0-d')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();
        $run_2 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-1-d-after')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();
        $run_3 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-2-d-after')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();


        //        dd($run_1);

        // Getting data from data table
        $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
        $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
        $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

        // Merge static run data
        $data = array_merge($data_1, $data_2);
        $static_data = array_merge($data, $data_3);

        // Creating data set
        $values = null;
        foreach ($static_data as $value) {
            $value['time'] = strtotime($value['time']) * 1000;

            $values[] = $value;
        }

        // if current data is null
        if ($values == null) {
            $current_date = Carbon::yesterday();
            $current_date = $current_date->toDateString();

            $date = $current_date . ' 00:00:00';

            // Creating Dates
            $date = DateTime::createFromFormat('Y-m-d H:i:s', $date)->format('Y-m-d H:i:s');
            $date_1_start = date('Y-m-d H:i:s', strtotime($date));
            $date_1_end = date('Y-m-d 23:00:00', strtotime($date));
            $date_2_start = date('Y-m-d H:i:s', strtotime('+ 1 day', strtotime($date)));
            $date_2_end = date('Y-m-d 23:00:00', strtotime('+ 1 day', strtotime($date)));
            $date_3_start = date('Y-m-d H:i:s', strtotime('+ 2 day', strtotime($date)));
            $date_3_end = date('Y-m-d 23:00:00', strtotime('+ 2 day', strtotime($date)));

            // Getting static station runs from run view
            $run_1 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-0-d')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();
            $run_2 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-1-d-after')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();
            $run_3 = Runview::where('variable', 'Precipitation')->where('type', 'Forecast-2-d-after')->where('station', $station)->whereIn('name', ['cloud-1', 'evening_18hrs'])->where('source', $source)->first();

            // Getting data from data table
            $data_1 = $run_1->data()->where('time', '<=', $date_1_end)->where('time', '>=', $date_1_start)->orderBy('time', 'asc')->get()->toArray();
            $data_2 = $run_2->data()->where('time', '<=', $date_2_end)->where('time', '>=', $date_2_start)->orderBy('time', 'asc')->get()->toArray();
            $data_3 = $run_3->data()->where('time', '<=', $date_3_end)->where('time', '>=', $date_3_start)->orderBy('time', 'asc')->get()->toArray();

            // Merge static run data
            $data = array_merge($data_1, $data_2);
            $static_data = array_merge($data, $data_3);

            // Creating data set
            $values = null;
            foreach ($static_data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        return $values;
    }

    public function dataObserved($station)
    {
        // Getting static station run from run view
        if ($station == 'Orugodawatta') {
            $run_1 = Runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $run_1 = Runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }


        // Getting data from data table
        // Getting data from data table
        $data = null;
        if ($run_1 !== null) {
            $data = $run_1->data()->select(DB::raw("REPLACE(MAX(time),SUBSTRING_INDEX(MAX(time), ' ', -1),SEC_TO_TIME((TIME_TO_SEC(MAX(time)) DIV 3600) * 3600)) as time"), DB::raw('SUM(value) as value'))
                ->where('time', '>=', Carbon::now()->subDays(7))
                ->groupBy(DB::raw('UNIX_TIMESTAMP(time) / 3600'))
                ->get()->toArray();
        }

        // Creating data set
        $values = null;
        if ($data !== null) {
            foreach ($data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $value['value'] = $value['value'];

                $values[] = $value;
            }
        }

        return $values;
    }

    public function dataObservedHours($station, $hours)
    {
        // Getting static station run from run view
        if ($station == 'Orugodawatta') {
            $run_1 = Runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('name', 'CUrW IoT')
                ->where('start_date', '!=', null)
                ->first();
        } else {
            $run_1 = Runview::where('station', $station)
                ->where('variable', 'Precipitation')
                ->where('source', 'WeatherStation')
                ->where('start_date', '!=', null)
                ->first();
        }


        // Getting data from data table
        $data = null;
        if ($run_1 !== null) {
            $data = $run_1->data()->select(DB::raw("REPLACE(MAX(time),SUBSTRING_INDEX(MAX(time), ' ', -1),SEC_TO_TIME((TIME_TO_SEC(MAX(time)) DIV 3600) * 3600)) as time"), DB::raw('SUM(value) as value'))
                ->where('time', '>=', Carbon::now()->subhours($hours))
                ->groupBy(DB::raw('UNIX_TIMESTAMP(time) / 3600'))
                ->get()->toArray();
        }

        // Creating data set
        $count = 0;
        if ($data !== null) {
            foreach ($data as $value) {
                $count += $value['value'];
            }
        }

        return $count;
    }

    public function dataObservedRain($station, $start)
    {
        // Getting static station run from run view
        $run_1 = null;
        $run_1 = Runview::where('station', $station)
            ->where('variable', 'Precipitation')
            ->where('source', 'WeatherStation')
            ->where('start_date', '!=', null)
            ->first();


        // Getting data from data table
        $data = null;
        if ($run_1 !== null) {
            $data = $run_1->data()
                ->select(['time', 'value'])
                ->where('time', '>=', $start)
                ->where('time', '<=', Carbon::parse($start)->addDays(2)->format('Y-m-d 23:30:00'))
                ->orderBy('time', 'asc')
                ->get()
                ->toArray();
        }

        // Creating data set
        $values = null;
        if ($data !== null) {
            foreach ($data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $value['value'] = $value['value'];

                $values[] = $value;
            }
        }

        return $values;
    }

    public function dataObservedWL($station, $start)
    {
        $values = null;
        $data = null;

        $run = runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('station', $station)->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->first();

        if ($run !== null) {
            $data = $run->data()->where('time', '>=', Carbon::parse($start)->format('Y-m-d H:i:s'))->where('time', '<=', Carbon::parse($start)->addDays(2)->format('Y-m-d 23:30:00'))->orderBy('time', 'asc')->get()->toArray();
        }

        if ($data) {
            foreach ($data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }


        return $values;
    }

    public function dataObservedWLPublic($station, $start)
    {
        $values = null;
        $data = null;

        $run = runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('station', $station)->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->first();

        if ($run !== null) {
            $data = $run->data()->where('time', '>=', Carbon::parse($start)->format('Y-m-d H:i:s'))->where('time', '<=', Carbon::parse($start)->addDays(2)->format('Y-m-d 23:30:00'))->orderBy('time', 'asc')->get()->toArray();
        }

        if ($data) {
            foreach ($data as $value) {
                $value['time'] = strtotime($value['time']) * 1000;
                $values[] = $value;
            }
        }

        return $values;
    }

    public function getFloodEvent($station, $date)
    {
        $all_data = null;

        $date = $date . ' 00:00:00';
        $dynamic_date = Carbon::parse($date)->format('Y');

        $run_names = Runview::where('station', $station)->where('name', $dynamic_date . ' May Flood')->where('type', '!=', 'Forecast-0-d')->orderBy('type', 'asc')->get();

        // Getting data from Data table
        foreach ($run_names as $run) {
            $all_data[] = $run->data()->select(DB::raw('DISTINCT time'), DB::raw('value'))->orderBy('time', 'asc')->get();
        }

        // Merge Data table data
        $static_data = [];
        foreach ($all_data as $data) {
            $static_data = $data->toBase()->merge($static_data);
            $static_data = $static_data->sort();
        }

        dd($static_data->toArray());
    }

    public function getCoordinates($station)
    {
        return \App\Models\Stations\Station::where('name', $station)->first();
    }

    public function fourth()
    {
        return view('frontend.graphs.screens.4th-screen');
    }

    public function fifth()
    {
        return view('frontend.graphs.screens.5th-screen');
    }

    public function sixth()
    {
        $klb_values = $this->dataPR("klb_mean", 'wrf0');
        $klb = array(
            'values' => $klb_values
        );

        $kub_values = $this->dataPR("kub_mean", 'wrf0');
        $kub = array(
            'values' => $kub_values
        );

        $mahapallegama_values = $this->dataPR("wrf_80.256645_7.156975", 'wrf0');
        $mahapallegama = array(
            'values' => $mahapallegama_values
        );

        $hingurana_values = $this->dataPR("wrf_80.420021_6.913757", 'wrf0');
        $hingurana = array(
            'values' => $hingurana_values
        );

        $hanwella_p_values = $this->dataPR("wrf_80.093269_6.913757", 'wrf0');
        $hanwella_p = array(
            'values' => $hanwella_p_values
        );

        $hatton_values = $this->dataPR("wrf_80.610626_7.238014", 'wrf0');
        $hatton = array(
            'values' => $hatton_values
        );

        $hanwella_d = $this->discharge("Hanwella");
        $hanwella_d = array(
            'values' => $hanwella_d
        );

        $glencourse_values = $this->dataPR("Glencourse", 'wrf0');
        $glencourse = array(
            'values' => $glencourse_values
        );

        $data = array(
            'klb' => $klb,
            'kub' => $kub,
            'mahapallegama' => $mahapallegama,
            'hingurana' => $hingurana,
            'hanwella_p' => $hanwella_p,
            'hatton' => $hatton,
            'hanwella_d' => $hanwella_d,
            'glencourse' => $glencourse
        );

        return view('frontend.graphs.screens.6th-screen')->with(['data' => $data]);
    }

    public function seventh($source)
    {
        $ibattara2_values = $this->dataPR("wrf_79.848206_6.886719", $source);
        $ibattara2 = array(
            'values' => $ibattara2_values
        );

        $mahapallegama_values = $this->dataPR("wrf_80.256645_7.156975", 'wrf0');
        $mahapallegama = array(
            'values' => $mahapallegama_values
        );

        $orugoda_values = $this->dataPR("wrf_79.875435_6.940788", $source);
        $orugoda = array(
            'values' => $orugoda_values
        );



        $hatton_values = $this->dataPR("wrf_80.610626_7.238014", $source);
        $hatton = array(
            'values' => $hatton_values
        );

        $waga_values = $this->dataPR("wrf_80.120499_6.886719", $source);
        $waga = array(
            'values' => $waga_values
        );

        $hingurana_values = $this->dataPR("wrf_80.420021_6.913757", 'wrf0');
        $hingurana = array(
            'values' => $hingurana_values
        );

        $data = array(
            'ibattara2' => $ibattara2,
            'mahapallegama' => $mahapallegama,
            'orugoda' => $orugoda,
            //            'kottawa' => $kottawa,
            'hatton' => $hatton,
            'waga' => $waga,
            'hingurana' => $hingurana
        );

        return view('frontend.graphs.screens.7th-screen')->with(['data' => $data]);
    }

    public function seventhMultiple()
    {
        // wrf 0 data
        $ibattara2_values_wrf0 = $this->dataPR("wrf_79.848206_6.886719", 'wrf0');
        $ibattara2_wrf0 = array(
            'values' => $ibattara2_values_wrf0
        );

        $mahapallegama_values_wrf0 = $this->dataPR("wrf_80.256645_7.156975", 'wrf0');
        $mahapallegama_wrf0 = array(
            'values' => $mahapallegama_values_wrf0
        );

        $orugoda_values_wrf0 = $this->dataPR("wrf_79.875435_6.940788", 'wrf0');
        $orugoda_wrf0 = array(
            'values' => $orugoda_values_wrf0
        );

        $hatton_values_wrf0 = $this->dataPR("wrf_80.610626_7.238014", 'wrf0');
        $hatton_wrf0 = array(
            'values' => $hatton_values_wrf0
        );

        $waga_values_wrf0 = $this->dataPR("wrf_80.120499_6.886719", 'wrf0');
        $waga_wrf0 = array(
            'values' => $waga_values_wrf0
        );

        $hingurana_values_wrf0 = $this->dataPR("wrf_80.420021_6.913757", 'wrf0');
        $hingurana_wrf0 = array(
            'values' => $hingurana_values_wrf0
        );

        // wrf 1 data
        $ibattara2_values_wrf1 = $this->dataPR("wrf_79.848206_6.886719", 'wrf1');
        $ibattara2_wrf1 = array(
            'values' => $ibattara2_values_wrf1
        );

        $mahapallegama_values_wrf1 = $this->dataPR("wrf_80.256645_7.156975", 'wrf1');
        $mahapallegama_wrf1 = array(
            'values' => $mahapallegama_values_wrf1
        );

        $orugoda_values_wrf1 = $this->dataPR("wrf_79.875435_6.940788", 'wrf1');
        $orugoda_wrf1 = array(
            'values' => $orugoda_values_wrf1
        );

        $hatton_values_wrf1 = $this->dataPR("wrf_80.610626_7.238014", 'wrf1');
        $hatton_wrf1 = array(
            'values' => $hatton_values_wrf1
        );

        $waga_values_wrf1 = $this->dataPR("wrf_80.120499_6.886719", 'wrf1');
        $waga_wrf1 = array(
            'values' => $waga_values_wrf1
        );

        $hingurana_values_wrf1 = $this->dataPR("wrf_80.420021_6.913757", 'wrf1');
        $hingurana_wrf1 = array(
            'values' => $hingurana_values_wrf1
        );

        // wrf 2 data
        $ibattara2_values_wrf2 = $this->dataPR("wrf_79.848206_6.886719", 'wrf2');
        $ibattara2_wrf2 = array(
            'values' => $ibattara2_values_wrf2
        );

        $mahapallegama_values_wrf2 = $this->dataPR("wrf_80.256645_7.156975", 'wrf2');
        $mahapallegama_wrf2 = array(
            'values' => $mahapallegama_values_wrf2
        );

        $orugoda_values_wrf2 = $this->dataPR("wrf_79.875435_6.940788", 'wrf2');
        $orugoda_wrf2 = array(
            'values' => $orugoda_values_wrf2
        );

        $hatton_values_wrf2 = $this->dataPR("wrf_80.610626_7.238014", 'wrf2');
        $hatton_wrf2 = array(
            'values' => $hatton_values_wrf2
        );

        $waga_values_wrf2 = $this->dataPR("wrf_80.120499_6.886719", 'wrf2');
        $waga_wrf2 = array(
            'values' => $waga_values_wrf2
        );

        $hingurana_values_wrf2 = $this->dataPR("wrf_80.420021_6.913757", 'wrf2');
        $hingurana_wrf2 = array(
            'values' => $hingurana_values_wrf2
        );

        // wrf 3 data
        $ibattara2_values_wrf3 = $this->dataPR("wrf_79.848206_6.886719", 'wrf3');
        $ibattara2_wrf3 = array(
            'values' => $ibattara2_values_wrf3
        );

        $mahapallegama_values_wrf3 = $this->dataPR("wrf_80.256645_7.156975", 'wrf3');
        $mahapallegama_wrf3 = array(
            'values' => $mahapallegama_values_wrf3
        );

        $orugoda_values_wrf3 = $this->dataPR("wrf_79.875435_6.940788", 'wrf3');
        $orugoda_wrf3 = array(
            'values' => $orugoda_values_wrf3
        );

        $hatton_values_wrf3 = $this->dataPR("wrf_80.610626_7.238014", 'wrf3');
        $hatton_wrf3 = array(
            'values' => $hatton_values_wrf3
        );

        $waga_values_wrf3 = $this->dataPR("wrf_80.120499_6.886719", 'wrf3');
        $waga_wrf3 = array(
            'values' => $waga_values_wrf3
        );

        $hingurana_values_wrf3 = $this->dataPR("wrf_80.420021_6.913757", 'wrf3');
        $hingurana_wrf3 = array(
            'values' => $hingurana_values_wrf3
        );

        // wrf 4 data
        $ibattara2_values_wrf4 = $this->dataPR("wrf_79.848206_6.886719", 'wrf4');
        $ibattara2_wrf4 = array(
            'values' => $ibattara2_values_wrf4
        );

        $mahapallegama_values_wrf4 = $this->dataPR("wrf_80.256645_7.156975", 'wrf4');
        $mahapallegama_wrf4 = array(
            'values' => $mahapallegama_values_wrf4
        );

        $orugoda_values_wrf4 = $this->dataPR("wrf_79.875435_6.940788", 'wrf4');
        $orugoda_wrf4 = array(
            'values' => $orugoda_values_wrf4
        );

        $hatton_values_wrf4 = $this->dataPR("wrf_80.610626_7.238014", 'wrf4');
        $hatton_wrf4 = array(
            'values' => $hatton_values_wrf4
        );

        $waga_values_wrf4 = $this->dataPR("wrf_80.120499_6.886719", 'wrf4');
        $waga_wrf4 = array(
            'values' => $waga_values_wrf4
        );

        $hingurana_values_wrf4 = $this->dataPR("wrf_80.420021_6.913757", 'wrf4');
        $hingurana_wrf4 = array(
            'values' => $hingurana_values_wrf4
        );

        // wrf 4 data
        $ibattara2_values_wrf5 = $this->dataPR("wrf_79.848206_6.886719", 'wrf5');
        $ibattara2_wrf5 = array(
            'values' => $ibattara2_values_wrf5
        );

        $mahapallegama_values_wrf5 = $this->dataPR("wrf_80.256645_7.156975", 'wrf5');
        $mahapallegama_wrf5 = array(
            'values' => $mahapallegama_values_wrf5
        );

        $orugoda_values_wrf5 = $this->dataPR("wrf_79.875435_6.940788", 'wrf5');
        $orugoda_wrf5 = array(
            'values' => $orugoda_values_wrf5
        );

        $hatton_values_wrf5 = $this->dataPR("wrf_80.610626_7.238014", 'wrf5');
        $hatton_wrf5 = array(
            'values' => $hatton_values_wrf5
        );

        $waga_values_wrf5 = $this->dataPR("wrf_80.120499_6.886719", 'wrf5');
        $waga_wrf5 = array(
            'values' => $waga_values_wrf5
        );

        $hingurana_values_wrf5 = $this->dataPR("wrf_80.420021_6.913757", 'wrf5');
        $hingurana_wrf5 = array(
            'values' => $hingurana_values_wrf5
        );

        $wrf0 = array(
            'ibattara2' => $ibattara2_wrf0,
            'mahapallegama' => $mahapallegama_wrf0,
            'orugoda' => $orugoda_wrf0,
            'hatton' => $hatton_wrf0,
            'waga' => $waga_wrf0,
            'hingurana' => $hingurana_wrf0
        );

        $wrf1 = array(
            'ibattara2' => $ibattara2_wrf1,
            'mahapallegama' => $mahapallegama_wrf1,
            'orugoda' => $orugoda_wrf1,
            'hatton' => $hatton_wrf1,
            'waga' => $waga_wrf1,
            'hingurana' => $hingurana_wrf1
        );

        $wrf2 = array(
            'ibattara2' => $ibattara2_wrf2,
            'mahapallegama' => $mahapallegama_wrf2,
            'orugoda' => $orugoda_wrf2,
            'hatton' => $hatton_wrf2,
            'waga' => $waga_wrf2,
            'hingurana' => $hingurana_wrf2
        );

        $wrf3 = array(
            'ibattara2' => $ibattara2_wrf3,
            'mahapallegama' => $mahapallegama_wrf3,
            'orugoda' => $orugoda_wrf3,
            'hatton' => $hatton_wrf3,
            'waga' => $waga_wrf3,
            'hingurana' => $hingurana_wrf3
        );

        $wrf4 = array(
            'ibattara2' => $ibattara2_wrf4,
            'mahapallegama' => $mahapallegama_wrf4,
            'orugoda' => $orugoda_wrf4,
            'hatton' => $hatton_wrf4,
            'waga' => $waga_wrf4,
            'hingurana' => $hingurana_wrf4
        );

        $wrf5 = array(
            'ibattara2' => $ibattara2_wrf5,
            'mahapallegama' => $mahapallegama_wrf5,
            'orugoda' => $orugoda_wrf5,
            'hatton' => $hatton_wrf5,
            'waga' => $waga_wrf5,
            'hingurana' => $hingurana_wrf5
        );

        $data = array(
            'wrf0' => $wrf0,
            'wrf1' => $wrf1,
            'wrf2' => $wrf2,
            'wrf3' => $wrf3,
            'wrf4' => $wrf4,
            'wrf5' => $wrf5
        );

        return view('frontend.graphs.screens.7th-screen-multiple')->with(['data' => $data]);
    }

    public function eighth()
    {
        // Get coordinates
        set_time_limit(0);
        $coordinates = array(
            'ambatale_river' => $this->getCoordinates('Ambatale River'),
            'par_lake_side' => $this->getCoordinates('Parlimant Lake Side'),
            'dehiwala' => $this->getCoordinates('Dehiwala Canal'),
            'ambathale_outfull1' => $this->getCoordinates('Ambatale Outfull1'),
            'slrdc' => $this->getCoordinates('Near SLLRDC'),
            'salalihini_river' => $this->getCoordinates('Salalihini-River'),
            'kelani_mulla' => $this->getCoordinates('Kelani Mulla Outfall'),
            'n_street_river' => $this->getCoordinates('Nagalagam Street River'),
            'n_street' => $this->getCoordinates('Nagalagam Street'),
            'kotte_north' => $this->getCoordinates('Kotte North Canal'),
            'wellawatta_canal' => $this->getCoordinates('Wellawatta Canal-St Peters College'),
            'dem_canal' => $this->getCoordinates('Dematagoda Canal-Orugodawatta')
        );

        $ambathale_river_values = $this->dataWL("Ambatale River");
        $ambathale_river_values_m = $this->dataWLMike("Ambatale River");
        $ambathale_river_values_150 = $this->dataWL150("Ambatale River");
        $ambathale_river_values_250wi = $this->dataWL250WI("Ambatale River");
        $ambathale_river_values_hourly = $this->dataWL250HOURLY("Ambatale River");
        $ambathale_river = array(
            'values' => $ambathale_river_values,
            'm_values' => $ambathale_river_values_m,
            '150_values' => $ambathale_river_values_150,
            '250wi_values' => $ambathale_river_values_250wi,
            'hourly_values' => $ambathale_river_values_hourly
        );

        $par_lake_side_values = $this->dataWL("Parlimant Lake Side");
        $par_lake_side_values_m = $this->dataWLMike("Parlimant Lake Side");
        $par_lake_side_values_150 = $this->dataWL150("Parlimant Lake Side");
        $par_lake_side_values_250wi = $this->dataWL250WI("Parlimant Lake Side");
        $par_lake_side_values_hourly = $this->dataWL250HOURLY("Parlimant Lake Side");
        $par_lake_side = array(
            'values' => $par_lake_side_values,
            'm_values' => $par_lake_side_values_m,
            '150_values' => $par_lake_side_values_150,
            '250wi_values' => $par_lake_side_values_250wi,
            'hourly_values' => $par_lake_side_values_hourly
        );

        $dehiwala_values = $this->dataWL("Dehiwala Canal");
        $dehiwala_values_m = $this->dataWLMike("Dehiwala Canal");
        $dehiwala_values_150 = $this->dataWL150("Dehiwala Canal");
        $dehiwala_values_250wi = $this->dataWL250WI("Dehiwala Canal");
        $dehiwala_values_hourly = $this->dataWL250HOURLY("Dehiwala Canal");
        $dehiwala = array(
            'values' => $dehiwala_values,
            'm_values' => $dehiwala_values_m,
            '150_values' => $dehiwala_values_150,
            '250wi_values' => $dehiwala_values_250wi,
            'hourly_values' => $dehiwala_values_hourly
        );

        $ambathale_outfull1_values = $this->dataWL("Ambatale Outfull1");
        $ambathale_outfull1_values_m = $this->dataWLMike("Ambatale Outfall");
        $ambathale_outfull1_values_150 = $this->dataWL150("Ambatale Outfull1");
        $ambathale_outfull1_values_250wi = $this->dataWL250WI("Ambatale Outfull1");
        $ambathale_outfull1_values_hourly = $this->dataWL250HOURLY("Ambatale Outfull1");
        $ambathale_outfull1 = array(
            'values' => $ambathale_outfull1_values,
            'm_values' => $ambathale_outfull1_values_m,
            '150_values' => $ambathale_outfull1_values_150,
            '250wi_values' => $ambathale_outfull1_values_250wi,
            'hourly_values' => $ambathale_outfull1_values_hourly
        );

        $slrdc_values = $this->dataWL("Near SLLRDC");
        $slrdc_values_m = $this->dataWLMike("Near SLLRDC");
        $slrdc_values_150 = $this->dataWL150("Near SLLRDC");
        $slrdc_values_250wi = $this->dataWL250WI("Near SLLRDC");
        $slrdc_values_hourly = $this->dataWL250HOURLY("Near SLLRDC");
        $slrdc = array(
            'values' => $slrdc_values,
            'm_values' => $slrdc_values_m,
            '150_values' => $slrdc_values_150,
            '250wi_values' => $slrdc_values_250wi,
            'hourly_values' => $slrdc_values_hourly
        );

        $salalihini_river_values = $this->dataWL("Salalihini-River");
        $salalihini_river_values_m = $this->dataWLMike("Salalihini-River");
        $salalihini_river_values_150 = $this->dataWL150("Salalihini-River");
        $salalihini_river_values_250wi = $this->dataWL250WI("Salalihini-River");
        $salalihini_river_values_hourly = $this->dataWL250HOURLY("Salalihini-River");
        $salalihini_river = array(
            'values' => $salalihini_river_values,
            'm_values' => $salalihini_river_values_m,
            '150_values' => $salalihini_river_values_150,
            '250wi_values' => $salalihini_river_values_250wi,
            'hourly_values' => $salalihini_river_values_hourly
        );

        $kelani_mulla_values = $this->dataWL("Kelani Mulla Outfall");
        $kelani_mulla_values_m = $this->dataWLMike("Kelani Mulla Outfall");
        $kelani_mulla_values_150 = $this->dataWL150("Kelani Mulla Outfall");
        $kelani_mulla_values_250wi = $this->dataWL250WI("Kelani Mulla Outfall");
        $kelani_mulla_values_hourly = $this->dataWL250HOURLY("Kelani Mulla Outfall");
        //dd($kelani_mulla_values_150);
        $kelani_mulla = array(
            'values' => $kelani_mulla_values,
            'm_values' => $kelani_mulla_values_m,
            '150_values' => $kelani_mulla_values_150,
            '250wi_values' => $kelani_mulla_values_250wi,
            'hourly_values' => $kelani_mulla_values_hourly
        );

        $n_street_river_values = $this->dataWL("Nagalagam Street River");
        $n_street_river_values_m = $this->dataWLMike("Nagalagam Street River");
        $n_street_river_values_150 = $this->dataWL150("Nagalagam Street River");
        $n_street_river_values_250wi = $this->dataWL250WI("Nagalagam Street River");
        $n_street_river_values_hourly = $this->dataWL250HOURLY("Nagalagam Street River");
        $n_street_river = array(
            'values' => $n_street_river_values,
            'm_values' => $n_street_river_values_m,
            '150_values' => $n_street_river_values_150,
            '250wi_values' => $n_street_river_values_250wi,
            'hourly_values' => $n_street_river_values_hourly
        );

        $n_street_values = $this->dataWL("Nagalagam Street");
        $n_street_values_m = $this->dataWLMike("Nagalagam Street");
        $n_street_values_150 = $this->dataWL150("Nagalagam Street");
        $n_street_values_250wi = $this->dataWL250WI("Nagalagam Street");
        $n_street_values_hourly = $this->dataWL250HOURLY("Nagalagam Street");
        $n_street = array(
            'values' => $n_street_values,
            'm_values' => $n_street_values_m,
            '150_values' => $n_street_values_150,
            '250wi_values' => $n_street_values_250wi,
            'hourly_values' => $n_street_values_hourly
        );

        $kotte_north_values_values = $this->dataWL("Kotte North Canal");
        $kotte_north_values_values_m = $this->dataWLMike("Kotte North Canal");
        $kotte_north_values_values_150 = $this->dataWL150("Kotte North Canal");
        $kotte_north_values_values_250wi = $this->dataWL250WI("Kotte North Canal");
        $kotte_north_values_values_hourly = $this->dataWL250HOURLY("Kotte North Canal");
        $kotte_north = array(
            'values' => $kotte_north_values_values,
            'm_values' => $kotte_north_values_values_m,
            '150_values' => $kotte_north_values_values_150,
            '250wi_values' => $kotte_north_values_values_250wi,
            'hourly_values' => $kotte_north_values_values_hourly
        );

        $wellawatta_canal_values = $this->dataWL("Wellawatta Canal-St Peters College");
        $wellawatta_canal_values_m = $this->dataWLMike("Wellawatta Canal-St Peters College");
        $wellawatta_canal_values_150 = $this->dataWL150("Wellawatta Canal-St Peters College");
        $wellawatta_canal_values_250wi = $this->dataWL250WI("Wellawatta Canal-St Peters College");
        $wellawatta_canal_values_hourly = $this->dataWL250HOURLY("Wellawatta Canal-St Peters College");
        $wellawatta_canal = array(
            'values' => $wellawatta_canal_values,
            'm_values' => $wellawatta_canal_values_m,
            '150_values' => $wellawatta_canal_values_150,
            '250wi_values' => $wellawatta_canal_values_250wi,
            'hourly_values' => $wellawatta_canal_values_hourly
        );

        $dem_canal_values = $this->dataWL("Dematagoda Canal-Orugodawatta");
        $dem_canal_values_m = $this->dataWLMike("Dematagoda Canal-Orugodawatta");
        $dem_canal_values_150 = $this->dataWL150("Dematagoda Canal-Orugodawatta");
        $dem_canal_values_250wi = $this->dataWL250WI("Dematagoda Canal-Orugodawatta");
        $dem_canal_values_hourly = $this->dataWL250HOURLY("Dematagoda Canal-Orugodawatta");
        $dem_canal = array(
            'values' => $dem_canal_values,
            'm_values' => $dem_canal_values_m,
            '150_values' => $dem_canal_values_150,
            '250wi_values' => $dem_canal_values_250wi,
            'hourly_values' => $dem_canal_values_hourly
        );

        $data = array(
            'ambathale_river' => $ambathale_river,
            'par_lake_side' => $par_lake_side,
            'dehiwala' => $dehiwala,
            'ambathale_outfull1' => $ambathale_outfull1,
            'slrdc' => $slrdc,
            'salalihini_river' => $salalihini_river,
            'kelani_mulla' => $kelani_mulla,
            'n_street_river' => $n_street_river,
            'n_street' => $n_street,
            'kotte_north' => $kotte_north,
            'wellawatta_canal' => $wellawatta_canal,
            'dem_canal' => $dem_canal
        );

        return view('frontend.graphs.screens.8th-screen-test')->with(['data' => $data, 'coordinates' => $coordinates]);
    }

    public function alersWlevel()
    {
        // Get coordinates

        //        $coordinates = array(
        //            'ambatale_river' => $this->getCoordinates('Ambatale River'),
        //            'par_lake_side' => $this->getCoordinates('Parlimant Lake Side'),
        //            'dehiwala' => $this->getCoordinates('Dehiwala Canal'),
        //            'ambathale_outfull1' => $this->getCoordinates('Ambatale Outfull1'),
        //            'slrdc' => $this->getCoordinates('Near SLLRDC'),
        //            'salalihini_river' => $this->getCoordinates('Salalihini-River'),
        //            'kelani_mulla' => $this->getCoordinates('Kelani Mulla Outfall'),
        //            'n_street_river' => $this->getCoordinates('Nagalagam Street River'),
        //            'n_street' => $this->getCoordinates('Nagalagam Street'),
        //            'kotte_north' => $this->getCoordinates('Kotte North Canal'),
        //            'wellawatta_canal' => $this->getCoordinates('Wellawatta Canal-St Peters College'),
        //            'dem_canal' => $this->getCoordinates('Dematagoda Canal-Orugodawatta')
        //        );

        $ambathale_river_values = $this->dataWLMike("Ambatale River");
        $ambathale_river = array(
            'values' => $ambathale_river_values
        );

        $par_lake_side_values = $this->dataWLMike("Parlimant Lake Side");
        $par_lake_side = array(
            'values' => $par_lake_side_values
        );

        $ambathale_outfull1_values = $this->dataWLMike("Ambatale Outfall");
        $ambathale_outfull1 = array(
            'values' => $ambathale_outfull1_values
        );

        $n_street_river_values = $this->dataWLMike("Nagalagam Street River");
        $n_street_river = array(
            'values' => $n_street_river_values
        );

        $n_street_values = $this->dataWLMike("Nagalagam Street");
        $n_street = array(
            'values' => $n_street_values
        );

        $data = array(
            'ambathale_river' => $ambathale_river,
            'par_lake_side' => $par_lake_side,
            'ambathale_outfull1' => $ambathale_outfull1,
            'n_street_river' => $n_street_river,
            'n_street' => $n_street
        );
        //        dd($data);
        return view('frontend.graphs.screens.alerts-wl')->with(['data' => $data]);
    }

    public function ninth()
    {
        $f = file_get_contents("http://35.185.243.20:8080/admin/airflow/graph?dag_id=docker_wrf_run_prod_cts_v4");
        //        dd($f);
        //        exit;
        return view('frontend.graphs.screens.9th-screen')->with(['data' => $f]);
    }

    public function weatherStations()
    {
        set_time_limit(0);

        $mahapallegama_values = $this->dataObserved("Mahapallegama");
        $mahapallegama = array(
            'name' => 'Mahapallegama',
            'hours' => [$this->dataObservedHours("Mahapallegama", 3), $this->dataObservedHours("Mahapallegama", 6), $this->dataObservedHours("Mahapallegama", 12), $this->dataObservedHours("Mahapallegama", 24)],
            'values' => $mahapallegama_values
        );

        $hingurana_values = $this->dataObserved("Hingurana");
        $hingurana = array(
            'name' => 'Hingurana',
            'hours' => [$this->dataObservedHours("Hingurana", 3), $this->dataObservedHours("Hingurana", 6), $this->dataObservedHours("Hingurana", 12), $this->dataObservedHours("Hingurana", 24)],
            'values' => $hingurana_values
        );

        $mulleriyawa_values = $this->dataObserved("Mulleriyawa");
        $mulleriyawa = array(
            'name' => 'Mulleriyawa',
            'hours' => [$this->dataObservedHours("Mulleriyawa", 3), $this->dataObservedHours("Mulleriyawa", 6), $this->dataObservedHours("Mulleriyawa", 12), $this->dataObservedHours("Mulleriyawa", 24)],
            'values' => $mulleriyawa_values
        );

        $dickoya_values = $this->dataObserved("Dickoya");
        $dickoya = array(
            'name' => 'Dickoya',
            'hours' => [$this->dataObservedHours("Dickoya", 3), $this->dataObservedHours("Dickoya", 6), $this->dataObservedHours("Dickoya", 12), $this->dataObservedHours("Dickoya", 24)],
            'values' => $dickoya_values
        );

        $kottawa_values = $this->dataObserved("Kottawa North Dharmapala School");
        $kottawa = array(
            'name' => 'Kottawa',
            'hours' => [$this->dataObservedHours("Kottawa North Dharmapala School", 3), $this->dataObservedHours("Kottawa North Dharmapala School", 6), $this->dataObservedHours("Kottawa North Dharmapala School", 12), $this->dataObservedHours("Kottawa North Dharmapala School", 24)],
            'values' => $kottawa_values
        );

        $orugodawatta_values = $this->dataObserved("Orugodawatta");
        $orugoda = array(
            'name' => 'Orugodawatta',
            'hours' => [$this->dataObservedHours("Orugodawatta", 3), $this->dataObservedHours("Orugodawatta", 6), $this->dataObservedHours("Orugodawatta", 12), $this->dataObservedHours("Orugodawatta", 24)],
            'values' => $orugodawatta_values
        );

        $ibattara2_values = $this->dataObserved("IBATTARA2");
        $ibattara2 = array(
            'name' => 'Battaramulla',
            'hours' => [$this->dataObservedHours("IBATTARA2", 3), $this->dataObservedHours("IBATTARA2", 6), $this->dataObservedHours("IBATTARA2", 12), $this->dataObservedHours("IBATTARA2", 24)],
            'values' => $ibattara2_values
        );

        $waga_values = $this->dataObserved("Waga");
        $waga = array(
            'name' => 'Waga',
            'hours' => [$this->dataObservedHours("Waga", 3), $this->dataObservedHours("Waga", 6), $this->dataObservedHours("Waga", 12), $this->dataObservedHours("Waga", 24)],
            'values' => $waga_values
        );

        $kohuwala_values = $this->dataObserved("Kohuwala");
        $kohuwala = array(
            'name' => 'Kohuwala',
            'hours' => [$this->dataObservedHours("Kohuwala", 3), $this->dataObservedHours("Kohuwala", 6), $this->dataObservedHours("Kohuwala", 12), $this->dataObservedHours("Kohuwala", 24)],
            'values' => $kohuwala_values
        );

        $malabe_values = $this->dataObserved("Malabe");
        $malabe = array(
            'name' => 'Malabe',
            'hours' => [$this->dataObservedHours("Malabe", 3), $this->dataObservedHours("Malabe", 6), $this->dataObservedHours("Malabe", 12), $this->dataObservedHours("Malabe", 24)],
            'values' => $malabe_values
        );

        $mutwal_values = $this->dataObserved("Mutwal");
        $mutwal = array(
            'name' => 'Mutwal',
            'hours' => [$this->dataObservedHours("Mutwal", 3), $this->dataObservedHours("Mutwal", 6), $this->dataObservedHours("Mutwal", 12), $this->dataObservedHours("Mutwal", 24)],
            'values' => $mutwal_values
        );

        $urumewella_values = $this->dataObserved("Urumewella");
        $urumewella = array(
            'name' => 'Urumewella',
            'hours' => [$this->dataObservedHours("Urumewella", 3), $this->dataObservedHours("Urumewella", 6), $this->dataObservedHours("Urumewella", 12), $this->dataObservedHours("Urumewella", 24)],
            'values' => $urumewella_values
        );

        $kotikawatta_values = $this->dataObserved("Kotikawatta");
        $kotikawatta = array(
            'name' => 'Kotikawatta',
            'hours' => [$this->dataObservedHours("Kotikawatta", 3), $this->dataObservedHours("Kotikawatta", 6), $this->dataObservedHours("Kotikawatta", 12), $this->dataObservedHours("Kotikawatta", 24)],
            'values' => $kotikawatta_values
        );

        $jaffna_values = $this->dataObserved("Jaffna");
        $jaffna = array(
            'name' => 'Jaffna',
            'hours' => [$this->dataObservedHours("Jaffna", 3), $this->dataObservedHours("Jaffna", 6), $this->dataObservedHours("Jaffna", 12), $this->dataObservedHours("Jaffna", 24)],
            'values' => $jaffna_values
        );

        $stations = array(
            'ibattara2' => $ibattara2,
            'mahapallegama' => $mahapallegama,
            'orugoda' => $orugoda,
            'kottawa' => $kottawa,
            'mulleriyawa' => $mulleriyawa,
            //            'waga' => $waga,
            'kohuwala' => $kohuwala,
            'urumewella' => $urumewella,
            'malabe' => $malabe,
            'kotikawatta' => $kotikawatta,
            'dickoya' => $dickoya,
            'mutwal' => $mutwal,
            'jaffna' => $jaffna,
            'hingurana' => $hingurana
        );
        //        dd($stations);
        return view('frontend.graphs.screens.weather-stations')->with(['stations' => $stations]);
    }

    public function getCurwFCT($station, $st, $en)
    {
        // dd($station);
        // $run = DB::connection('mysql_curw_fct')->select(DB::raw('SELECT * FROM curw_fcst.run where curw_fcst.run.source=9 and curw_fcst.run.variable=2 and curw_fcst.run.unit=2 and station=' . $station['id']));
        $run = RunviewFct::where('source', 9)->where('variable', 2)->where('unit', 2)->where('station', $station)->orderBy('end_date', 'desc')->first();

        $forecasts = DataFct::where('id', $run['id'])
            ->where('fgt', $run['end_date'])
            ->where('time', '>', $st)
            ->where('time', '<', $en)
            ->orderBy('time', 'asc')
            ->get();
        // dd($forecasts);

        $values = [];

        if (!$forecasts->isEmpty()) {
            foreach ($forecasts as $key => $forecast) {
                $values[$key]['time'] = strtotime($forecast->time) * 1000;
                $values[$key]['value'] = $forecast->value;
            }
        }

        // dd($values);

        return $values;
    }

    public function tenth($start)
    {
        if (Carbon::parse($start) > Carbon::today()) {
            return redirect()->route('frontend.screen.tenth', Carbon::today()->format('Y-m-d'));
        }

        set_time_limit(0);

        $st = Carbon::now()->subHours(6)->format('Y-m-d H:i:s');
        $en = Carbon::now()->addHours(6)->format('Y-m-d H:i:s');

        $yakbedda_obs = $this->dataObservedWL('Yakbedda', $start);
        $yakbedda_250 = $this->dataWL250Obs('Yakbedda', $start);
        $yakbedda_150 = $this->dataWL150Obs('Yakbedda', $start);
        $yakbedda_mike = $this->dataWLMikeObs('Yakbedda', $start);
        $yakbedda_250h = $this->dataWL250HOURLYS("Yakbedda", $start);
        $yakbedda = array(
            'obs_values' => $yakbedda_obs,
            '250_values' => $yakbedda_250,
            '250h_values' => $yakbedda_250h,
            '150_values' => $yakbedda_150,
            'mike_values' => $yakbedda_mike,
            // 'fct_values' => $this->getCurwFCT(StationFct::where('id', 'LIKE', '12%')->where("name", "LIKE", "%Yakbedda")->first()['id'], $st, $en),
            'name' => 'Yakbedda',
            'class' => '.yakbedda',
            'coordinates' => $this->ObserveController->getCoordinates('Yakbedda')
        );

        $igurukade_obs = $this->dataObservedWL('Ingurukade', $start);
        $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $igurukade_250h = $this->dataWL250HOURLYS("Ingurukade Jn", $start);
        $igurukade = array(
            'obs_values' => $igurukade_obs,
            '250_values' => $igurukade_250,
            '250h_values' => $igurukade_250h,
            '150_values' => $igurukade_150,
            'mike_values' => $igurukade_mike,
            // 'fct_values' => $this->getCurwFCT(StationFct::where('name', 'LIKE', '%Ingurukade Jn')->first()['id'], $st, $en),
            'name' => 'Igurukade',
            'class' => '.igurukade',
            'coordinates' => $this->ObserveController->getCoordinates('Ingurukade')
        );

        $janakala_obs = $this->dataObservedWL('Janakala Kendraya', $start);
        $janakala_250 = $this->dataWL250Obs('JanakalaKendraya', $start);
        $janakala_150 = $this->dataWL150Obs('JanakalaKendraya', $start);
        $janakala_mike = $this->dataWLMikeObs('JanakalaKendraya', $start);
        $janakala_250h = $this->dataWL250HOURLYS("JanakalaKendraya", $start);
        $janakala = array(
            'obs_values' => $janakala_obs,
            '250_values' => $janakala_250,
            '250h_values' => $janakala_250h,
            '150_values' => $janakala_150,
            'mike_values' => $janakala_mike,
            // 'fct_values' => $this->getCurwFCT(StationFct::where('name', 'LIKE', '%JanakalaKendraya')->first()['id'], $st, $en),
            'name' => 'Janakala Kendraya',
            'class' => '.janakala',
            'coordinates' => $this->ObserveController->getCoordinates('Janakala Kendraya')
        );

        $wellampitiya_obs = $this->dataObservedWL('Wellampitiya', $start);
        $wellampitiya_250 = $this->dataWL250Obs('Wellampitiya', $start);
        $wellampitiya_150 = $this->dataWL150Obs('Wellampitiya', $start);
        $wellampitiya_mike = $this->dataWLMikeObs('Wellampitiya', $start);
        $wellampitiya_250h = $this->dataWL250HOURLYS("Wellampitiya", $start);
        $wellampitiya = array(
            'obs_values' => $wellampitiya_obs,
            '250_values' => $wellampitiya_250,
            '250h_values' => $wellampitiya_250h,
            '150_values' => $wellampitiya_150,
            'mike_values' => $wellampitiya_mike,
            // 'fct_values' => $this->getCurwFCT(StationFct::where('name', 'LIKE', '%Wellampitiya')->first()['id'], $st, $en),
            'name' => 'Wellampitiya',
            'class' => '.wellampitiya',
            'coordinates' => $this->ObserveController->getCoordinates('Wellampitiya')
        );

        $wellawatta_obs = $this->dataObservedWL('Wellawatta', $start);
        $wellawatta_250 = $this->dataWL250Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_150 = $this->dataWL150Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_mike = $this->dataWLMikeObs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_250h = $this->dataWL250HOURLYS("Wellawatta Canal-St Peters College", $start);
        $wellawatta = array(
            'obs_values' => $wellawatta_obs,
            '250_values' => $wellawatta_250,
            '250h_values' => $wellawatta_250h,
            '150_values' => $wellawatta_150,
            'mike_values' => $wellawatta_mike,
            // 'fct_values' => $this->getCurwFCT(StationFct::where('name', 'LIKE', '%Wellawatta Canal-St Peters College')->first()['id'], $st, $en),
            'name' => 'Wellawatta',
            'class' => '.wellawatta',
            'coordinates' => $this->ObserveController->getCoordinates('Wellawatta')
        );

        $stations = array(
            'yakbedda' => $yakbedda,
            'igurukade' => $igurukade,
            'janakala' => $janakala,
            'wellampitiya' => $wellampitiya,
            'wellawatta' => $wellawatta
        );
        // dd($stations);

        return view('frontend.graphs.screens.10th-screen')->with(['stations' => $stations, 'start' => strtotime($st) * 1000, 'end' => strtotime($en) * 1000]);
    }

    public function tenthPublic()
    {
        $start = Carbon::today();

        set_time_limit(0);

        $yakbedda_obs = $this->dataObservedWLPublic('Yakbedda', $start);
        $yakbedda_250 = $this->dataWL250ObsPublic('Yakbedda', $start);
        $yakbedda_150 = $this->dataWL150ObsPublic('Yakbedda', $start);
        $yakbedda_mike = $this->dataWLMikeObsPublic('Yakbedda', $start);
        $yakbedda = array(
            'obs_values' => $yakbedda_obs,
            '250_values' => $yakbedda_250,
            '150_values' => $yakbedda_150,
            'mike_values' => $yakbedda_mike,
            'name' => 'Yakbedda',
            'class' => '.yakbedda',
            'coordinates' => $this->ObserveController->getCoordinates('Yakbedda')
        );

        $igurukade_obs = $this->dataObservedWLPublic('Ingurukade', $start);
        $igurukade_250 = $this->dataWL250ObsPublic('Ingurukade Jn', $start);
        $igurukade_150 = $this->dataWL150ObsPublic('Ingurukade Jn', $start);
        $igurukade_mike = $this->dataWLMikeObsPublic('Ingurukade Jn', $start);
        $igurukade = array(
            'obs_values' => $igurukade_obs,
            '250_values' => $igurukade_250,
            '150_values' => $igurukade_150,
            'mike_values' => $igurukade_mike,
            'name' => 'Igurukade',
            'class' => '.igurukade',
            'coordinates' => $this->ObserveController->getCoordinates('Ingurukade')
        );

        $janakala_obs = $this->dataObservedWLPublic('Janakala Kendraya', $start);
        $janakala_250 = $this->dataWL250ObsPublic('JanakalaKendraya', $start);
        $janakala_150 = $this->dataWL150ObsPublic('JanakalaKendraya', $start);
        $janakala_mike = $this->dataWLMikeObsPublic('JanakalaKendraya', $start);
        $janakala = array(
            'obs_values' => $janakala_obs,
            '250_values' => $janakala_250,
            '150_values' => $janakala_150,
            'mike_values' => $janakala_mike,
            'name' => 'Janakala Kendraya',
            'class' => '.janakala',
            'coordinates' => $this->ObserveController->getCoordinates('Janakala Kendraya')
        );

        $wellampitiya_obs = $this->dataObservedWLPublic('Wellampitiya', $start);
        $wellampitiya_250 = $this->dataWL250ObsPublic('Wellampitiya', $start);
        $wellampitiya_150 = $this->dataWL150ObsPublic('Wellampitiya', $start);
        $wellampitiya_mike = $this->dataWLMikeObsPublic('Wellampitiya', $start);
        $wellampitiya = array(
            'obs_values' => $wellampitiya_obs,
            '250_values' => $wellampitiya_250,
            '150_values' => $wellampitiya_150,
            'mike_values' => $wellampitiya_mike,
            'name' => 'Wellampitiya',
            'class' => '.wellampitiya',
            'coordinates' => $this->ObserveController->getCoordinates('Wellampitiya')
        );

        $wellawatta_obs = $this->dataObservedWLPublic('Wellawatta', $start);
        $wellawatta_250 = $this->dataWL250ObsPublic('Wellawatta Canal-St Peters College', $start);
        $wellawatta_150 = $this->dataWL150ObsPublic('Wellawatta Canal-St Peters College', $start);
        $wellawatta_mike = $this->dataWLMikeObsPublic('Wellawatta Canal-St Peters College', $start);
        $wellawatta = array(
            'obs_values' => $wellawatta_obs,
            '250_values' => $wellawatta_250,
            '150_values' => $wellawatta_150,
            'mike_values' => $wellawatta_mike,
            'name' => 'Wellawatta',
            'class' => '.wellawatta',
            'coordinates' => $this->ObserveController->getCoordinates('Wellawatta')
        );

        $stations = array(
            'yakbedda' => $yakbedda,
            'igurukade' => $igurukade,
            'janakala' => $janakala,
            'wellampitiya' => $wellampitiya,
            'wellawatta' => $wellawatta
        );


        return view('frontend.graphs.screens.10th-screen-public')->with(['stations' => $stations]);
    }

    public function tenthTest($start)
    {
        if (Carbon::parse($start) >= Carbon::today()) {
            return redirect()->route('frontend.screen.tenth.test', Carbon::yesterday()->format('Y-m-d'));
        }


        set_time_limit(0);

        $yakbedda_obs = $this->dataObservedWL('Yakbedda', $start);
        $yakbedda_250 = $this->dataWL250Obs('Yakbedda', $start);
        $yakbedda_150 = $this->dataWL150Obs('Yakbedda', $start);
        $yakbedda_mike = $this->dataWLMikeObs('Yakbedda', $start);
        $yakbedda = array(
            'obs_values' => $yakbedda_obs,
            '250_values' => $yakbedda_250,
            '150_values' => $yakbedda_150,
            'mike_values' => $yakbedda_mike,
            'name' => 'Yakbedda',
            'class' => '.yakbedda',
            'coordinates' => $this->ObserveController->getCoordinates('Yakbedda')
        );

        $igurukade_obs = $this->dataObservedWL('Ingurukade', $start);
        $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $igurukade = array(
            'obs_values' => $igurukade_obs,
            '250_values' => $igurukade_250,
            '150_values' => $igurukade_150,
            'mike_values' => $igurukade_mike,
            'name' => 'Igurukade',
            'class' => '.igurukade',
            'coordinates' => $this->ObserveController->getCoordinates('Ingurukade')
        );

        $janakala_obs = $this->dataObservedWL('Janakala Kendraya', $start);
        $janakala_250 = $this->dataWL250Obs('JanakalaKendraya', $start);
        $janakala_150 = $this->dataWL150Obs('JanakalaKendraya', $start);
        $janakala_mike = $this->dataWLMikeObs('JanakalaKendraya', $start);
        $janakala = array(
            'obs_values' => $janakala_obs,
            '250_values' => $janakala_250,
            '150_values' => $janakala_150,
            'mike_values' => $janakala_mike,
            'name' => 'Janakala Kendraya',
            'class' => '.janakala',
            'coordinates' => $this->ObserveController->getCoordinates('Janakala Kendraya')
        );

        $wellampitiya_obs = $this->dataObservedWL('Wellampitiya', $start);
        $wellampitiya_250 = $this->dataWL250Obs('Wellampitiya', $start);
        $wellampitiya_150 = $this->dataWL150Obs('Wellampitiya', $start);
        $wellampitiya_mike = $this->dataWLMikeObs('Wellampitiya', $start);
        $wellampitiya = array(
            'obs_values' => $wellampitiya_obs,
            '250_values' => $wellampitiya_250,
            '150_values' => $wellampitiya_150,
            'mike_values' => $wellampitiya_mike,
            'name' => 'Wellampitiya',
            'class' => '.wellampitiya',
            'coordinates' => $this->ObserveController->getCoordinates('Wellampitiya')
        );

        $wellawatta_obs = $this->dataObservedWL('Wellawatta', $start);
        $wellawatta_250 = $this->dataWL250Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_150 = $this->dataWL150Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_mike = $this->dataWLMikeObs('Wellawatta Canal-St Peters College', $start);
        $wellawatta = array(
            'obs_values' => $wellawatta_obs,
            '250_values' => $wellawatta_250,
            '150_values' => $wellawatta_150,
            'mike_values' => $wellawatta_mike,
            'name' => 'Wellawatta',
            'class' => '.wellawatta',
            'coordinates' => $this->ObserveController->getCoordinates('Wellawatta')
        );

        $stations = array(
            'yakbedda' => $yakbedda,
            'igurukade' => $igurukade,
            'janakala' => $janakala,
            'wellampitiya' => $wellampitiya,
            'wellawatta' => $wellawatta
        );


        return view('frontend.graphs.screens.10th-test')->with(['stations' => $stations]);
    }

    public function eleventh()

    {
        set_time_limit(0);

        $values = null;

        $date = Carbon::today()->format('Y-m-d');

        $runs = runview::whereIn('name', ['Leecom', 'A&T Labs'])->where('source', 'WeatherStation')->where('variable', 'Waterlevel')->where('type', 'Observed')->get();

        if ($runs->isNotEmpty()) {
            foreach ($runs as $key => $run) {
                $run_data = $run
                    ->data()
                    ->select(['time', 'value'])
                    ->orderBy('time', 'desc')
                    ->first();

                $max_run_data = $run
                    ->data()
                    ->selectRaw('MAX(value) as value, hour(time) as hour, time')
                    ->where('time', '>=', Carbon::now()->subHours(1))
                    ->groupBy(['hour', 'time'])
                    ->orderBy('value', 'desc')
                    ->first();

                if (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 1) {
                    $color = 'green';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) <= 3) {
                    $color = 'orange';
                } elseif (Carbon::parse($run_data['time'])->diffInHours(Carbon::now()) < 6) {
                    $color = 'orange';
                } else {
                    $color = 'red';
                }

                // Setting station alert level colors
                $status = 'Normal';
                $normal = '<span style="color: rgba(0,118,140,0.79);">Status: Normal</span>';
                $alert = '<span style="color: rgba(134,140,5,0.79);">Status: Alert</span>';
                $flood = '<span style="color: rgba(140,17,0,0.79);">Status: Flood</span>';

                if ($run->station == 'Diyasaru Uyana') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Ingurukade') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Janakala Kendraya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Leecom WL Guage') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellampitiya') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 1.2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Wellawatta') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                if ($run->station == 'Yakbedda') {
                    $stations[$key]['name'] = $run->station;
                    if ($max_run_data['value'] >= 1.7) {
                        $status = $alert;
                    } elseif ($max_run_data['value'] >= 2) {
                        $status = $flood;
                    } else {
                        $status = $normal;
                    }
                }

                $values[] = array('name' => $run->station, 'color' => $color, 'last_updated' => Carbon::parse($run_data['time'])->diffForHumans(), 'source' => $run->name, 'water_level' => round($run_data['value'], 2) . ' m', 'status' => $status);
            }



            return view('frontend.observations.water-level-status-curw')->with(['stations' => $values, 'date' => $date]);
        } else {
            echo 'something went wrong, please contact the developer, Thank you!';
        }
    }

    public function twelveth($start)
    {
        if (Carbon::parse($start) > Carbon::today()) {
            return redirect()->route('frontend.screen.twelveth', Carbon::today()->format('Y-m-d'));
        }

        set_time_limit(0);

        $yakbedda_obs = $this->dataObservedWL('Yakbedda', $start);
        $yakbedda_robs = $this->dataObservedRain('Kotikawatta', $start);
        $yakbedda_250 = $this->dataWL250Obs('Yakbedda', $start);
        $yakbedda_150 = $this->dataWL150Obs('Yakbedda', $start);
        $yakbedda_mike = $this->dataWLMikeObs('Yakbedda', $start);
        $yakbedda = array(
            'obs_values' => $yakbedda_obs,
            'robs_values' => $yakbedda_robs,
            '250_values' => $yakbedda_250,
            '150_values' => $yakbedda_150,
            'mike_values' => $yakbedda_mike,
            'name' => 'Yakbedda',
            'class' => 'yakbedda',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Yakbedda')
        );

        $igurukade_obs = $this->dataObservedWL('Ingurukade', $start);
        $igurukade_robs = $this->dataObservedRain('Kotikawatta', $start);
        $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $igurukade = array(
            'obs_values' => $igurukade_obs,
            'robs_values' => $igurukade_robs,
            '250_values' => $igurukade_250,
            '150_values' => $igurukade_150,
            'mike_values' => $igurukade_mike,
            'name' => 'Igurukade',
            'class' => 'igurukade',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Ingurukade')
        );

        $diyasaru_ups_obs = $this->dataObservedWL('Leecom WL Guage', $start);
        $diyasaru_ups_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $diyasaru_ups = array(
            'obs_values' => $diyasaru_ups_obs,
            'robs_values' => $diyasaru_ups_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Diyasaru Uyana Upstream',
            'class' => 'diyasaru-uyana-ups',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Leecom WL Guage')
        );


        $diyasaru_obs = $this->dataObservedWL('Diyasaru Uyana', $start);
        $diyasaru_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $diyasaru_uyana = array(
            'obs_values' => $diyasaru_obs,
            'robs_values' => $diyasaru_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Diyasaru Uyana',
            'class' => 'diyasaru-uyana',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Diyasaru Uyana')
        );

        $ranwala_obs = $this->dataObservedWL('Ranwala Bridge', $start);
        $ranwala_robs = $this->dataObservedRain('Urumewella', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $ranwala = array(
            'obs_values' => $ranwala_obs,
            'robs_values' => $ranwala_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Ranwala Bridge',
            'class' => 'ranwala',
            'type' => 'river',
            'coordinates' => $this->ObserveController->getCoordinates('Ranwala Bridge')
        );

        $mattakkuliya_obs = $this->dataObservedWL('Mattakkuliya', $start);
        $mattakkuliya_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $mattakkuliya = array(
            'obs_values' => $mattakkuliya_obs,
            'robs_values' => $mattakkuliya_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Mattakkuliya',
            'class' => 'mattakkuliya',
            'type' => 'river',
            'coordinates' => $this->ObserveController->getCoordinates('Mattakkuliya')
        );

        $janakala_obs = $this->dataObservedWL('Janakala Kendraya', $start);
        $janakala_robs = $this->dataObservedRain('IBATTARA2', $start);
        $janakala_250 = $this->dataWL250Obs('JanakalaKendraya', $start);
        $janakala_150 = $this->dataWL150Obs('JanakalaKendraya', $start);
        $janakala_mike = $this->dataWLMikeObs('JanakalaKendraya', $start);
        $janakala = array(
            'obs_values' => $janakala_obs,
            'robs_values' => $janakala_robs,
            '250_values' => $janakala_250,
            '150_values' => $janakala_150,
            'mike_values' => $janakala_mike,
            'name' => 'Janakala Kendraya',
            'class' => 'janakala',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Janakala Kendraya')
        );

        $wellampitiya_obs = $this->dataObservedWL('Wellampitiya', $start);
        $wellampitiya_robs = $this->dataObservedRain('Kotikawatta', $start);
        $wellampitiya_250 = $this->dataWL250Obs('Wellampitiya', $start);
        $wellampitiya_150 = $this->dataWL150Obs('Wellampitiya', $start);
        $wellampitiya_mike = $this->dataWLMikeObs('Wellampitiya', $start);
        $wellampitiya = array(
            'obs_values' => $wellampitiya_obs,
            'robs_values' => $wellampitiya_robs,
            '250_values' => $wellampitiya_250,
            '150_values' => $wellampitiya_150,
            'mike_values' => $wellampitiya_mike,
            'name' => 'Wellampitiya',
            'class' => 'wellampitiya',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Wellampitiya')
        );

        $wellawatta_obs = $this->dataObservedWL('Wellawatta', $start);
        $wellawatta_robs = $this->dataObservedRain('Kottawa North Dharmapala School', $start);
        $wellawatta_250 = $this->dataWL250Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_150 = $this->dataWL150Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_mike = $this->dataWLMikeObs('Wellawatta Canal-St Peters College', $start);
        $wellawatta = array(
            'obs_values' => $wellawatta_obs,
            'robs_values' => $wellawatta_robs,
            '250_values' => $wellawatta_250,
            '150_values' => $wellawatta_150,
            'mike_values' => $wellawatta_mike,
            'name' => 'Wellawatta',
            'class' => 'wellawatta',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Wellawatta')
        );

        $stations = array(
            'yakbedda' => $yakbedda,
            'igurukade' => $igurukade,
            'janakala' => $janakala,
            'wellampitiya' => $wellampitiya,
            'ranwala' => $ranwala,
            'diyasaru_ups' => $diyasaru_ups,
            'diyasaru_uyana' => $diyasaru_uyana,
            'mattakkuliya' => $mattakkuliya,
            'wellampitiya' => $wellampitiya,
            'wellawatta' => $wellawatta
        );

        // dd($stations);s

        return view('frontend.graphs.screens.12th-screen')->with(['stations' => $stations]);
    }

    public function twelvethPublic()
    {
        $start = Carbon::today();
        if (Carbon::parse($start) > Carbon::today()) {
            return redirect()->route('frontend.screen.twelveth', Carbon::today()->format('Y-m-d'));
        }

        set_time_limit(0);

        $yakbedda_obs = $this->dataObservedWL('Yakbedda', $start);
        $yakbedda_robs = $this->dataObservedRain('Kotikawatta', $start);
        $yakbedda_250 = $this->dataWL250Obs('Yakbedda', $start);
        $yakbedda_150 = $this->dataWL150Obs('Yakbedda', $start);
        $yakbedda_mike = $this->dataWLMikeObs('Yakbedda', $start);
        $yakbedda = array(
            'obs_values' => $yakbedda_obs,
            'robs_values' => $yakbedda_robs,
            '250_values' => $yakbedda_250,
            '150_values' => $yakbedda_150,
            'mike_values' => $yakbedda_mike,
            'name' => 'Yakbedda',
            'class' => 'yakbedda',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Yakbedda')
        );

        $igurukade_obs = $this->dataObservedWL('Ingurukade', $start);
        $igurukade_robs = $this->dataObservedRain('Kotikawatta', $start);
        $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $igurukade = array(
            'obs_values' => $igurukade_obs,
            'robs_values' => $igurukade_robs,
            '250_values' => $igurukade_250,
            '150_values' => $igurukade_150,
            'mike_values' => $igurukade_mike,
            'name' => 'Igurukade',
            'class' => 'igurukade',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Ingurukade')
        );

        $diyasaru_ups_obs = $this->dataObservedWL('Leecom WL Guage', $start);
        $diyasaru_ups_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $diyasaru_ups = array(
            'obs_values' => $diyasaru_ups_obs,
            'robs_values' => $diyasaru_ups_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Diyasaru Uyana Upstream',
            'class' => 'diyasaru-uyana-ups',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Leecom WL Guage')
        );


        $diyasaru_obs = $this->dataObservedWL('Diyasaru Uyana', $start);
        $diyasaru_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $diyasaru_uyana = array(
            'obs_values' => $diyasaru_obs,
            'robs_values' => $diyasaru_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Diyasaru Uyana',
            'class' => 'diyasaru-uyana',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Diyasaru Uyana')
        );

        $ranwala_obs = $this->dataObservedWL('Ranwala Bridge', $start);
        $ranwala_robs = $this->dataObservedRain('Urumewella', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $ranwala = array(
            'obs_values' => $ranwala_obs,
            'robs_values' => $ranwala_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Ranwala Bridge',
            'class' => 'ranwala',
            'type' => 'river',
            'coordinates' => $this->ObserveController->getCoordinates('Ranwala Bridge')
        );

        $mattakkuliya_obs = $this->dataObservedWL('Mattakkuliya', $start);
        $mattakkuliya_robs = $this->dataObservedRain('IBATTARA2', $start);
        // $igurukade_250 = $this->dataWL250Obs('Ingurukade Jn', $start);
        // $igurukade_150 = $this->dataWL150Obs('Ingurukade Jn', $start);
        // $igurukade_mike = $this->dataWLMikeObs('Ingurukade Jn', $start);
        $mattakkuliya = array(
            'obs_values' => $mattakkuliya_obs,
            'robs_values' => $mattakkuliya_robs,
            '250_values' => null,
            '150_values' => null,
            'mike_values' => null,
            'name' => 'Mattakkuliya',
            'class' => 'mattakkuliya',
            'type' => 'river',
            'coordinates' => $this->ObserveController->getCoordinates('Mattakkuliya')
        );

        $janakala_obs = $this->dataObservedWL('Janakala Kendraya', $start);
        $janakala_robs = $this->dataObservedRain('IBATTARA2', $start);
        $janakala_250 = $this->dataWL250Obs('JanakalaKendraya', $start);
        $janakala_150 = $this->dataWL150Obs('JanakalaKendraya', $start);
        $janakala_mike = $this->dataWLMikeObs('JanakalaKendraya', $start);
        $janakala = array(
            'obs_values' => $janakala_obs,
            'robs_values' => $janakala_robs,
            '250_values' => $janakala_250,
            '150_values' => $janakala_150,
            'mike_values' => $janakala_mike,
            'name' => 'Janakala Kendraya',
            'class' => 'janakala',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Janakala Kendraya')
        );

        $wellampitiya_obs = $this->dataObservedWL('Wellampitiya', $start);
        $wellampitiya_robs = $this->dataObservedRain('Kotikawatta', $start);
        $wellampitiya_250 = $this->dataWL250Obs('Wellampitiya', $start);
        $wellampitiya_150 = $this->dataWL150Obs('Wellampitiya', $start);
        $wellampitiya_mike = $this->dataWLMikeObs('Wellampitiya', $start);
        $wellampitiya = array(
            'obs_values' => $wellampitiya_obs,
            'robs_values' => $wellampitiya_robs,
            '250_values' => $wellampitiya_250,
            '150_values' => $wellampitiya_150,
            'mike_values' => $wellampitiya_mike,
            'name' => 'Wellampitiya',
            'class' => 'wellampitiya',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Wellampitiya')
        );

        $wellawatta_obs = $this->dataObservedWL('Wellawatta', $start);
        $wellawatta_robs = $this->dataObservedRain('Kottawa North Dharmapala School', $start);
        $wellawatta_250 = $this->dataWL250Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_150 = $this->dataWL150Obs('Wellawatta Canal-St Peters College', $start);
        $wellawatta_mike = $this->dataWLMikeObs('Wellawatta Canal-St Peters College', $start);
        $wellawatta = array(
            'obs_values' => $wellawatta_obs,
            'robs_values' => $wellawatta_robs,
            '250_values' => $wellawatta_250,
            '150_values' => $wellawatta_150,
            'mike_values' => $wellawatta_mike,
            'name' => 'Wellawatta',
            'class' => 'wellawatta',
            'type' => 'canal',
            'coordinates' => $this->ObserveController->getCoordinates('Wellawatta')
        );

        $stations = array(
            'yakbedda' => $yakbedda,
            'igurukade' => $igurukade,
            'janakala' => $janakala,
            'wellampitiya' => $wellampitiya,
            'ranwala' => $ranwala,
            'diyasaru_ups' => $diyasaru_ups,
            'diyasaru_uyana' => $diyasaru_uyana,
            'mattakkuliya' => $mattakkuliya,
            'wellampitiya' => $wellampitiya,
            'wellawatta' => $wellawatta
        );

        // dd($stations);

        return view('frontend.graphs.screens.12th-screen-public')->with(['stations' => $stations]);
    }
}
