@extends('frontend.layouts.dynamic')

@section('after-styles')
    <script defer src="https://use.fontawesome.com/releases/v5.0.6/js/all.js"></script>
    <link rel="stylesheet" href="https://js.arcgis.com/4.8/esri/css/main.css">
    <style>
        .card {
            margin-top: 30px;
        }

        .card-header-1 {
            width: 98%;
            margin: -20px auto 20px auto;
            padding: 25px 5px 10px 5px;
            background: linear-gradient(60deg, #038DDD, #095EAE);
            -webkit-box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
            -moz-box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
            box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
        }

        .div-raised {
            -webkit-box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
            -moz-box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
            box-shadow: 0px 10px 17px -6px rgba(0, 0, 0, 0.75);
        }

        table.top tr td {
            padding: 6px 12px;
            color: #292929;
            font-weight: 500;
        }
    </style>
@endsection

@section('content')

    <div class="container">
        <div class="card">
            <div class="card-header-1 blue">
                <h3 class="text-center"><strong><i class="fas fa-map"></i> 2016 Flood Extent - Kolonnawa
                        Division</strong></h3>
            </div>

            <div class="card-body">
                <div class="row">
                    <div class="col-md-12">
                        {{--<h5 class="text-center" style="color: #151515;"></h5>--}}
                        <div class="div-raised" id='map'
                             style='width: 100%; height: 450px;'></div>
                    </div>
                </div>
                <hr>
                <div class="row">

                </div>
            </div>
        </div>
    </div>

@endsection

@section('after-scripts')

    <script src="https://js.arcgis.com/4.8/"></script>
    <script>
        require([
                "esri/Map",
                "esri/views/MapView",
                "esri/widgets/Search",
                "esri/layers/FeatureLayer",
                "dojo/domReady!"
            ],
            function (
                Map, MapView,
                Search,
                FeatureLayer
            ) {

                var map = new Map({
                    basemap: "topo"
                });

                var view = new MapView({
                    container: "map",
                    map: map,

                    extent: { // autocasts as new Extent()
                        xmin: 79.872497,
                        ymin: 6.911751,
                        xmax: 79.956849,
                        ymax: 6.958296,
                        spatialReference: 4326
                    }
                });

                /********************
                 * Add feature layers
                 ********************/

                    // Carbon storage of trees in Warren Wilson College.
                var flood_depth = new FeatureLayer({
                        portalItem: { // autocasts as new PortalItem()
                            id: "22af71340f644f1cab51814544cfbd30"
                        }
                    });

                var water_body = new FeatureLayer({
                    portalItem: { // autocasts as new PortalItem()
                        id: "a653f64675714de3b551f117e7f9cb88"
                    }
                });

                var gn_divisions = new FeatureLayer({
                    portalItem: { // autocasts as new PortalItem()
                        id: "fe860b52251f470f9b0deffa51f7a6a0"
                    },
                    definitionExpression: "DSD_N  = 'Kolonnawa'"
                });

                view.when(function () {
                    /********************
                     * Add search widget
                     ********************/

                    var searchWidget = new Search({
                        includeDefaultSources: false,
                        view: view,
                        popupOpenOnSelect: false,
                        sources: [{
                            featureLayer: gn_divisions,
                            searchFields: ["GND_N"],
                            displayField: "GND_N",
                            exactMatch: true,
                            // outFields: ["*"],
                            name: "GN Divisions",
                            placeholder: "example: Orugodawatta",
                        }]
                    });

                    // the top left corner of the view
                    view.ui.add(searchWidget, {
                        position: "top-right",
                        index: 0
                    });

                });

                view.on("click", function (event) {
                    event.stopPropagation();
                    var screenPoint = {
                        x: event.x,
                        y: event.y
                    }

                    // Get the coordinates of the click on the view
                    // around the decimals to 3 decimals
                    var lat = Math.round(event.mapPoint.latitude * 1000) / 1000;
                    var lon = Math.round(event.mapPoint.longitude * 1000) /
                        1000;

                    // Search for graphics at the clicked location
                    view.hitTest(screenPoint).then(function (response) {
                        if (response.results.length) {
                            var division_graphic = response.results.filter(function (result) {
                                // check if the graphic belongs to the layer of interest
                                return result.graphic.layer === gn_divisions;
                            })[0].graphic;

                            var flood_graphic = response.results.filter(function (result) {
                                // check if the graphic belongs to the layer of interest
                                return result.graphic.layer === flood_depth;
                            })[0].graphic;

                            // do something with the result graphic
                            console.log(division_graphic.attributes);
                            console.log(flood_graphic.attributes);

                            if (flood_graphic.attributes !== [] && division_graphic.attributes !== []) {
                                var content =
                                    "<table class='table table-responsive-sm table-striped' style='font-size: 11px; margin: 0 auto;'>" +
                                    "<tr><td style='font-weight: 600;'>GS Division:</td>" +
                                    "<td>" + division_graphic.attributes['GND_N'] + "</td></tr>" +

                                    "<tr><td style='font-weight: 600;'>Flood Depth:</td>" +
                                    "<td>" + flood_graphic.attributes['Var'] + "</td></tr>" +

                                    "<tr><td style='font-weight: 600;'>Geocode:</td>" +
                                    "<td>" + "[" + lon + ", " + lat + "]" + "</td></tr>" +
                                    "</table>"

                                view.popup.open({
                                    // Set the popup's title to the coordinates of the clicked location
                                    title: "<h5 class='text-center'>Kolonnawa DS Division</h5>",
                                    content: content,
                                    location: event.mapPoint // Set the location of the popup to the clicked location
                                    // position: "bottom-right"
                                });

                            }
                        }
                    });
                });

                map.add(gn_divisions);
                map.add(flood_depth);
                map.add(water_body);

            });
    </script>
    {{--<script>--}}
    {{--require([--}}
    {{--"esri/Map",--}}
    {{--"esri/views/MapView",--}}
    {{--"esri/widgets/Search",--}}
    {{--// "esri/geometry/screenPoint",--}}
    {{--"esri/layers/FeatureLayer",--}}
    {{--"dojo/domReady!"--}}
    {{--],--}}
    {{--function(--}}
    {{--Map, MapView,--}}
    {{--Search,--}}
    {{--// ScreenPoint,--}}
    {{--FeatureLayer--}}
    {{--) {--}}

    {{--var map = new Map({--}}
    {{--basemap: "topo"--}}
    {{--});--}}

    {{--var view = new MapView({--}}
    {{--container: "map",--}}
    {{--map: map,--}}

    {{--extent: { // autocasts as new Extent()--}}
    {{--xmin: 79.872497,--}}
    {{--ymin: 6.911751,--}}
    {{--xmax: 79.956849,--}}
    {{--ymax: 6.958296,--}}
    {{--spatialReference: 4326--}}
    {{--}--}}
    {{--});--}}

    {{--/********************--}}
    {{--* Add feature layer--}}
    {{--********************/--}}

    {{--// Carbon storage of trees in Warren Wilson College.--}}
    {{--var featureLayer = new FeatureLayer({--}}
    {{--// url: "https://services8.arcgis.com/x1jRahQ58x0opxIe/arcgis/rest/services/2016_30/FeatureServer/0?token=BJixaty7PKapoRU8Kv-iiU3d-WG8z0Xz5ThnnRNvBCYdCeJSM00QWvUyWMQfgizuWlcenTOOHv1a5JRSf-A4HRb8c4wAc0f464CXWjqVG1ezpwB0wTX0dAVRBLG8nU90uJRr238RW_7RhOCdjqRCRGKLpknafSkTq55xFNGl6rF8syfYKp9BdOo0qTYu1mOi9b_CR-Qu0ckA9xgRZe073WJdGn_p5qHLaH0S-WzFXrSujeOzi4Qx_vdLuYu4OK7Z",--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "22af71340f644f1cab51814544cfbd30"--}}
    {{--},--}}
    {{--outFields: ["*"],--}}
    {{--// definitionExpression: "DSD_N  = 'Kolonnawa'",--}}
    {{--popupTemplate: {--}}
    {{--title: "Water Level",--}}
    {{--content: "{Var}"--}}
    {{--}--}}
    {{--});--}}

    {{--var featureLayer1 = new FeatureLayer({--}}
    {{--url: "https://services8.arcgis.com/x1jRahQ58x0opxIe/arcgis/rest/services/2017_Flood/FeatureServer/0?token=gaUgrB0erPzZMdh_gObnvWTXSgvvjdT0pSf-ywka4kT2J1lXX25VF-uF1RSapWACNr3w0lf04YnN2C_z1Lduo-5L4eBG9BGVBL9Ohk_oUFOsffIOOYFalJHKvKaZjmvIKNsExvJuS7q2L8sPnlWzYHRSih7lgVLkOp7mLPpNU8TE2H5i2CKzKs17T3Lg0p2ATb2PEAWU0Qy94X1ko-71K6gCMiHPaFrdqjDe3AFuCMVL8ML8uwMGwikLgMYPMeJs"--}}
    {{--});--}}

    {{--/********************--}}
    {{--* Add feature layer--}}
    {{--********************/--}}
    {{--var featureLayer2 = new FeatureLayer({--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "fe860b52251f470f9b0deffa51f7a6a0"--}}
    {{--},--}}
    {{--definitionExpression: "DSD_N  = 'Kolonnawa'",--}}
    {{--outFields: ["*"]--}}
    {{--});--}}

    {{--view.when(function() {--}}

    {{--// Carbon storage of trees in Warren Wilson College.--}}

    {{--/********************--}}
    {{--* Add search widget--}}
    {{--********************/--}}

    {{--var searchWidget = new Search({--}}
    {{--view: view,--}}
    {{--allPlaceholder: "Name",--}}
    {{--sources: [{--}}
    {{--featureLayer: featureLayer2,--}}
    {{--searchFields: ["GND_N"],--}}
    {{--displayField: "GND_N",--}}
    {{--exactMatch: false,--}}
    {{--outFields: ["*"],--}}
    {{--name: "GN Divisions",--}}
    {{--placeholder: "example: Orugodawatta",--}}
    {{--}]--}}
    {{--});--}}

    {{--// the top left corner of the view--}}
    {{--view.ui.add(searchWidget, {--}}
    {{--position: "top-right",--}}
    {{--index: 0--}}
    {{--});--}}

    {{--// return featureLayer.when(function() {--}}
    {{--//     var query = featureLayer.createQuery();--}}
    {{--//     query.where = "DSD_N LIKE '%Kolonnawa%'";--}}
    {{--//     return featureLayer.queryFeatures(query);--}}
    {{--// });--}}

    {{--});--}}

    {{--view.on("click", function(event) {--}}
    {{--event.stopPropagation();--}}
    {{--var screenPoint = {--}}
    {{--x: event.x,--}}
    {{--y: event.y--}}
    {{--}--}}

    {{--// Get the coordinates of the click on the view--}}
    {{--// around the decimals to 3 decimals--}}
    {{--var lat = Math.round(event.mapPoint.latitude * 1000) / 1000;--}}
    {{--var lon = Math.round(event.mapPoint.longitude * 1000) /--}}
    {{--1000;--}}

    {{--// Search for graphics at the clicked location--}}
    {{--view.hitTest(screenPoint).then(function(response) {--}}
    {{--if (response.results.length) {--}}
    {{--var graphic = response.results.filter(function(result) {--}}
    {{--// check if the graphic belongs to the layer of interest--}}
    {{--return result.graphic.layer;--}}
    {{--})[0].graphic;--}}

    {{--// do something with the result graphic--}}
    {{--// console.log(graphic.attributes);--}}

    {{--view.popup.open({--}}
    {{--// Set the popup's title to the coordinates of the clicked location--}}
    {{--title: "Water Level",--}}
    {{--content: "value: " + graphic.attributes['Var'] + "<br>Geocode: [" + lon + ", " + lat + "]",--}}
    {{--location: event.mapPoint // Set the location of the popup to the clicked location--}}
    {{--});--}}
    {{--}--}}
    {{--});--}}
    {{--// event.stopPropagation();--}}
    {{--// console.log(event);--}}
    {{--// Get the coordinates of the click on the view--}}
    {{--// around the decimals to 3 decimals--}}
    {{--// var lat = Math.round(event.mapPoint.latitude * 1000) / 1000;--}}
    {{--// var lon = Math.round(event.mapPoint.longitude * 1000) /--}}
    {{--//   1000;--}}

    {{--// view.popup.open({--}}
    {{--//   // Set the popup's title to the coordinates of the clicked location--}}
    {{--//   title: "Reverse geocode: [" + lon + ", " + lat + "]",--}}
    {{--//   location: event.mapPoint // Set the location of the popup to the clicked location--}}
    {{--// });--}}
    {{--});--}}

    {{--// map.add(featureLayer2);--}}
    {{--map.add(featureLayer);--}}
    {{--map.add(featureLayer1);--}}

    {{--});--}}
    {{--</script>--}}
    {{--<script>--}}
    {{--require([--}}
    {{--"esri/Map",--}}
    {{--"esri/views/MapView",--}}
    {{--"esri/widgets/Search",--}}
    {{--"esri/layers/FeatureLayer",--}}

    {{--"dojo/domReady!"--}}
    {{--],--}}
    {{--function(--}}
    {{--Map, MapView,--}}
    {{--Search,--}}
    {{--FeatureLayer--}}
    {{--) {--}}

    {{--var map = new Map({--}}
    {{--basemap: "topo"--}}
    {{--});--}}

    {{--var view = new MapView({--}}
    {{--container: "map",--}}
    {{--map: map,--}}

    {{--extent: { // autocasts as new Extent()--}}
    {{--xmin: 79.872497,--}}
    {{--ymin: 6.911751,--}}
    {{--xmax: 79.956849,--}}
    {{--ymax: 6.958296,--}}
    {{--spatialReference: 4326--}}
    {{--}--}}
    {{--});--}}

    {{--/********************--}}
    {{--* Add feature layer--}}
    {{--********************/--}}

    {{--// Carbon storage of trees in Warren Wilson College.--}}
    {{--var featureLayer = new FeatureLayer({--}}
    {{--// url: "https://services8.arcgis.com/x1jRahQ58x0opxIe/arcgis/rest/services/2016_30/FeatureServer/0?token=BJixaty7PKapoRU8Kv-iiU3d-WG8z0Xz5ThnnRNvBCYdCeJSM00QWvUyWMQfgizuWlcenTOOHv1a5JRSf-A4HRb8c4wAc0f464CXWjqVG1ezpwB0wTX0dAVRBLG8nU90uJRr238RW_7RhOCdjqRCRGKLpknafSkTq55xFNGl6rF8syfYKp9BdOo0qTYu1mOi9b_CR-Qu0ckA9xgRZe073WJdGn_p5qHLaH0S-WzFXrSujeOzi4Qx_vdLuYu4OK7Z",--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "22af71340f644f1cab51814544cfbd30"--}}
    {{--},--}}
    {{--outFields: ["*"],--}}
    {{--// definitionExpression: "DSD_N  = 'Kolonnawa'",--}}
    {{--// popupTemplate: {--}}
    {{--//   title: "{name}",--}}
    {{--//   content: [{--}}
    {{--//     type: "fields",--}}
    {{--//     fieldInfos: [ {--}}
    {{--//       fieldName: "var"--}}
    {{--//     }]--}}
    {{--//   }]--}}
    {{--// }--}}
    {{--});--}}

    {{--var featureLayer1 = new FeatureLayer({--}}
    {{--url: "https://services8.arcgis.com/x1jRahQ58x0opxIe/arcgis/rest/services/2017_Flood/FeatureServer/0?token=gaUgrB0erPzZMdh_gObnvWTXSgvvjdT0pSf-ywka4kT2J1lXX25VF-uF1RSapWACNr3w0lf04YnN2C_z1Lduo-5L4eBG9BGVBL9Ohk_oUFOsffIOOYFalJHKvKaZjmvIKNsExvJuS7q2L8sPnlWzYHRSih7lgVLkOp7mLPpNU8TE2H5i2CKzKs17T3Lg0p2ATb2PEAWU0Qy94X1ko-71K6gCMiHPaFrdqjDe3AFuCMVL8ML8uwMGwikLgMYPMeJs"--}}
    {{--});--}}


    {{--/********************--}}
    {{--* Add feature layer--}}
    {{--********************/--}}
    {{--var featureLayer2 = new FeatureLayer({--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "fe860b52251f470f9b0deffa51f7a6a0"--}}
    {{--},--}}
    {{--definitionExpression: "DSD_N  = 'Kolonnawa'",--}}
    {{--outFields: ["*"]--}}
    {{--});--}}

    {{--view.when(function () {--}}



    {{--// Carbon storage of trees in Warren Wilson College.--}}


    {{--/********************--}}
    {{--* Add search widget--}}
    {{--********************/--}}

    {{--var searchWidget = new Search({--}}
    {{--view: view,--}}
    {{--allPlaceholder: "Name",--}}
    {{--sources: [{--}}
    {{--featureLayer: featureLayer2,--}}
    {{--searchFields: ["GND_N"],--}}
    {{--displayField: "GND_N",--}}
    {{--exactMatch: false,--}}
    {{--outFields: ["*"],--}}
    {{--name: "GN Divisions",--}}
    {{--placeholder: "example: Orugodawatta",--}}
    {{--}]--}}
    {{--});--}}

    {{--// the top left corner of the view--}}
    {{--view.ui.add(searchWidget, {--}}
    {{--position: "top-right",--}}
    {{--index: 0--}}
    {{--});--}}

    {{--// return featureLayer.when(function() {--}}
    {{--//     var query = featureLayer.createQuery();--}}
    {{--//     query.where = "DSD_N LIKE '%Kolonnawa%'";--}}
    {{--//     return featureLayer.queryFeatures(query);--}}
    {{--// });--}}

    {{--});--}}


    {{--// map.add(featureLayer2);--}}
    {{--map.add(featureLayer);--}}
    {{--map.add(featureLayer1);--}}

    {{--});--}}
    {{--</script>--}}
    {{--<script>--}}
    {{--require([--}}
    {{--"esri/views/MapView",--}}
    {{--"esri/widgets/Legend",--}}
    {{--"esri/WebMap",--}}
    {{--"esri/widgets/Search",--}}
    {{--"esri/layers/FeatureLayer",--}}
    {{--"esri/tasks/support/Query",--}}
    {{--"esri/tasks/QueryTask",--}}
    {{--"dojo/promise/all",--}}
    {{--"dojo/domReady!"--}}
    {{--],--}}
    {{--function (--}}
    {{--MapView, Legend, WebMap, Search, FeatureLayer, Query, QueryTask, all--}}
    {{--) {--}}
    {{--var webmap = new WebMap({--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "82364c07112840d7ad7b9785e9dfd71f"--}}
    {{--}--}}
    {{--});--}}



    {{--var view = new MapView({--}}
    {{--container: "map",--}}
    {{--map: webmap,--}}
    {{--popup: "Data",--}}
    {{--extent: { // autocasts as new Extent()--}}
    {{--xmin: 79.872497,--}}
    {{--ymin: 6.911751,--}}
    {{--xmax: 79.956849,--}}
    {{--ymax: 6.958296,--}}
    {{--spatialReference: 4326--}}
    {{--}--}}
    {{--});--}}

    {{--// event handler that fires each time an action is clicked.--}}
    {{--view.popup.on("trigger-action", function(event){--}}
    {{--view.popup.open({--}}
    {{--title: "Results",--}}
    {{--content: "This is some content"--}}
    {{--});--}}
    {{--});--}}

    {{--// Find a layer with title "US Counties"--}}
    {{--//                 var foundLayer = webmap.allLayers.find(function(layer) {--}}
    {{--//                     return layer.DSD_N === "Kolonnawa";--}}
    {{--//                 });--}}
    {{--//--}}
    {{--// // Create a filtered collection of the non-group layers--}}
    {{--//                 var nonGroupLayers = webmap.allLayers.filter(function(layer) {--}}
    {{--//                     return !foundLayer.layers;--}}
    {{--//                 });--}}
    {{--//--}}
    {{--//                 // Listen for any layer being added or removed in the Map--}}
    {{--//                 webmap.allLayers.on("change", function(event) {--}}
    {{--//                     console.log("Layer added: ", event.added);--}}
    {{--//                     console.log("Layer removed: ", event.removed);--}}
    {{--//                     console.log("Layer moved: ", event.moved);--}}
    {{--//                 });--}}

    {{--// Define query sql expression--}}
    {{--// var query = new Query();--}}
    {{--// query.where = "DSD_N like '%Kolonnawa%'"--}}
    {{--// query.outFields = ["*"];--}}
    {{--// query.returnGeometry = true;--}}
    {{--//--}}
    {{--// // Define the query task--}}
    {{--// var queryTask = new QueryTask({--}}
    {{--//     portalItem: { // autocasts as new PortalItem()--}}
    {{--//         id: "fe860b52251f470f9b0deffa51f7a6a0"--}}
    {{--//     }--}}
    {{--// });--}}
    {{--//--}}
    {{--// // Execute the query--}}
    {{--// queryTask.execute(query)--}}
    {{--//     .then(function (result) {--}}
    {{--//         console.log(result.features.length)--}}
    {{--//     })--}}
    {{--//     .otherwise(function (e) {--}}
    {{--//         console.log(e);--}}
    {{--//     });--}}

    {{--var featureLayer = new FeatureLayer({--}}
    {{--portalItem: { // autocasts as new PortalItem()--}}
    {{--id: "fe860b52251f470f9b0deffa51f7a6a0"--}}
    {{--}--}}
    {{--// setDefinitionExpression("DSD_N = 'Kolonnawa'")--}}
    {{--});--}}
    {{--// // featureLayer.definitionExpression ("DSD_N = 'Kolonnawa'");--}}
    {{--//--}}
    {{--// var query = new Query();--}}
    {{--// query.where = "DSD_N LIKE '%Kolonnawa%'";--}}
    {{--//--}}
    {{--// featureLayer.queryObjectIds(query).then(function(ids){--}}
    {{--//     console.log(ids);  // an array of object IDs--}}
    {{--// });--}}
    {{--//--}}
    {{--// webmap.add(featureLayer);--}}

    {{--webmap.load()--}}
    {{--.then(function() {--}}
    {{--// load the basemap to get its layers created--}}
    {{--return webmap.basemap.load();--}}
    {{--})--}}
    {{--.then(function() {--}}
    {{--// grab all the layers and load them--}}
    {{--var allLayers = webmap.allLayers;--}}

    {{--var promises = allLayers.map(function(layer) {--}}
    {{--return layer.load();--}}
    {{--});--}}
    {{--return all(promises.toArray());--}}
    {{--})--}}
    {{--.then(function(layers) {--}}
    {{--// each layer load promise resolves with the layer--}}
    {{--// console.log("all " + allLayers + " layers loaded" + JSON.parse(allLayers));--}}
    {{--// console.log($.parseJSON(layers));--}}
    {{--})--}}
    {{--.catch(function(error) {--}}
    {{--console.error(error);--}}
    {{--});--}}

    {{--view.when(function () {--}}

    {{--/********************--}}
    {{--* Add feature layer--}}
    {{--********************/--}}


    {{--// Carbon storage of trees in Warren Wilson College.--}}


    {{--/********************--}}
    {{--* Add search widget--}}
    {{--********************/--}}

    {{--var searchWidget = new Search({--}}
    {{--view: view,--}}
    {{--allPlaceholder: "Name",--}}
    {{--sources: [{--}}
    {{--featureLayer: featureLayer,--}}
    {{--searchFields: ["GND_N"],--}}
    {{--displayField: "GND_N",--}}
    {{--exactMatch: false,--}}
    {{--outFields: ["*"],--}}
    {{--name: "GN Divisions",--}}
    {{--placeholder: "example: Orugodawatta",--}}
    {{--}]--}}
    {{--});--}}

    {{--// the top left corner of the view--}}
    {{--view.ui.add(searchWidget, {--}}
    {{--position: "top-right",--}}
    {{--index: 0--}}
    {{--});--}}

    {{--// return featureLayer.when(function() {--}}
    {{--//     var query = featureLayer.createQuery();--}}
    {{--//     query.where = "DSD_N LIKE '%Kolonnawa%'";--}}
    {{--//     return featureLayer.queryFeatures(query);--}}
    {{--// });--}}

    {{--});--}}


    {{--});--}}
    {{--</script>--}}
@endsection